searchData={"content_type":"text/markdown","items":[{"doc":"Pre-trained `Axon` models for easy inference and boosted training.\n\nBumblebee provides state-of-the-art, configurable `Axon` models. On\ntop of that, it streamlines the process of loading pre-trained models\nby integrating with Hugging Face Hub and [🤗 Transformers](https://github.com/huggingface/transformers).","ref":"Bumblebee.html","title":"Bumblebee","type":"module"},{"doc":"You can load one of the supported models by specifying the model repository:\n\n    {:ok, model_info} = Bumblebee.load_model({:hf, \"bert-base-uncased\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"bert-base-uncased\"})\n\nThen you are ready to make predictions:\n\n    inputs = Bumblebee.apply_tokenizer(tokenizer, \"Hello Bumblebee!\")\n    outputs = Axon.predict(model_info.model, model_info.params, inputs)\n\n#","ref":"Bumblebee.html#module-usage","title":"Usage - Bumblebee","type":"module"},{"doc":"On top of bare models, Bumblebee provides a number of **\"servings\"**\nthat act as end-to-end pipelines for specific tasks.\n\n    serving = Bumblebee.Text.fill_mask(model_info, tokenizer)\n    Nx.Serving.run(serving, \"The capital of [MASK] is Paris.\")\n    #=> %{\n    #=>   predictions: [\n    #=>     %{score: 0.9279842972755432, token: \"france\"},\n    #=>     %{score: 0.008412551134824753, token: \"brittany\"},\n    #=>     %{score: 0.007433671969920397, token: \"algeria\"},\n    #=>     %{score: 0.004957548808306456, token: \"department\"},\n    #=>     %{score: 0.004369721747934818, token: \"reunion\"}\n    #=>   ]\n    #=> }\n\nAs you can see the **serving** takes care of pre-processing the\ntext input, runs the model and also post-processes its output into\nmore structured data. In the above example we `run` serving on the\nfly, however for production usage you can start serving as a process\nand it will automatically batch requests from multiple clients.\nProcessing inputs in batches is usually much more efficient, since\nit can take advantage of parallel capabilities of the target device,\nwhich is particularly relevant in case of GPU. For more details read\nthe `Nx.Serving` docs.\n\nFor more examples see the [Examples](examples.livemd) notebook.\n\n> ##","ref":"Bumblebee.html#module-tasks","title":"Tasks - Bumblebee","type":"module"},{"doc":">\n> The models are generally large, so make sure to configure an efficient\n> `Nx` backend, such as `EXLA` or `Torchx`.","ref":"Bumblebee.html#module-note-info","title":"Note {: .info} - Bumblebee","type":"module"},{"doc":"Featurizes `input` with the given featurizer.","ref":"Bumblebee.html#apply_featurizer/3","title":"Bumblebee.apply_featurizer/3","type":"function"},{"doc":"* `:defn_options` - the options for JIT compilation. Note that\n    this is only relevant for featurizers implemented with Nx.\n    Defaults to `[]`","ref":"Bumblebee.html#apply_featurizer/3-options","title":"Options - Bumblebee.apply_featurizer/3","type":"function"},{"doc":"featurizer = Bumblebee.configure(Bumblebee.Vision.ConvNextFeaturizer)\n    {:ok, img} = StbImage.read_file(path)\n    inputs = Bumblebee.apply_featurizer(featurizer, [img])","ref":"Bumblebee.html#apply_featurizer/3-examples","title":"Examples - Bumblebee.apply_featurizer/3","type":"function"},{"doc":"Tokenizes and encodes `input` with the given tokenizer.","ref":"Bumblebee.html#apply_tokenizer/3","title":"Bumblebee.apply_tokenizer/3","type":"function"},{"doc":"* `:add_special_tokens` - whether to add special tokens. Defaults\n    to `true`\n\n  * `:pad_direction` - the padding direction, either `:right` or\n    `:left`. Defaults to `:right`\n\n  * `:return_attention_mask` - whether to return attention mask for\n    encoded sequence. Defaults to `true`\n\n  * `:return_token_type_ids` - whether to return token type ids for\n    encoded sequence. Defaults to `true`\n\n  * `:return_special_tokens_mask` - whether to return special tokens\n    mask for encoded sequence. Defaults to `false`\n\n  * `:return_offsets` - whether to return token offsets for encoded\n    sequence. Defaults to `false`\n\n  * `:length` - applies fixed length padding or truncation to the\n    given input if set. Can be either a specific number or a list\n    of numbers. When a list is given, the smallest number that\n    exceeds all input lengths is used as the padding length","ref":"Bumblebee.html#apply_tokenizer/3-options","title":"Options - Bumblebee.apply_tokenizer/3","type":"function"},{"doc":"tokenizer = Bumblebee.load_tokenizer({:hf, \"bert-base-uncased\"})\n    inputs = Bumblebee.apply_tokenizer(tokenizer, [\"The capital of France is [MASK].\"])","ref":"Bumblebee.html#apply_tokenizer/3-examples","title":"Examples - Bumblebee.apply_tokenizer/3","type":"function"},{"doc":"Builds an `Axon` model according to the given specification.","ref":"Bumblebee.html#build_model/1","title":"Bumblebee.build_model/1","type":"function"},{"doc":"spec = Bumblebee.configure(Bumblebee.Vision.ResNet, architecture: :base, embedding_size: 128)\n    model = Bumblebee.build_model(spec)","ref":"Bumblebee.html#build_model/1-example","title":"Example - Bumblebee.build_model/1","type":"function"},{"doc":"Returns the directory where downloaded files are stored.","ref":"Bumblebee.html#cache_dir/0","title":"Bumblebee.cache_dir/0","type":"function"},{"doc":"Builds or updates a configuration object with the given options.\n\nExpects a configuration struct or a module supporting configuration.\nThese are usually configurable:\n\n  * model specification (`Bumblebee.ModelSpec`)\n\n  * featurizer (`Bumblebee.Featurizer`)\n\n  * scheduler (`Bumblebee.Scheduler`)","ref":"Bumblebee.html#configure/2","title":"Bumblebee.configure/2","type":"function"},{"doc":"To build a new configuration, pass a module:\n\n    featurizer = Bumblebee.configure(Bumblebee.Vision.ConvNextFeaturizer)\n    spec = Bumblebee.configure(Bumblebee.Vision.ResNet, architecture: :for_image_classification)\n\nSimilarly, you can update an existing configuration:\n\n    featurizer = Bumblebee.configure(featurizer, resize_method: :bilinear)\n    spec = Bumblebee.configure(spec, embedding_size: 128)","ref":"Bumblebee.html#configure/2-examples","title":"Examples - Bumblebee.configure/2","type":"function"},{"doc":"Loads featurizer from a model repository.","ref":"Bumblebee.html#load_featurizer/2","title":"Bumblebee.load_featurizer/2","type":"function"},{"doc":"* `:module` - the featurizer module. By default it is inferred\n    from the preprocessor configuration file, if that is not possible,\n    it must be specified explicitly","ref":"Bumblebee.html#load_featurizer/2-options","title":"Options - Bumblebee.load_featurizer/2","type":"function"},{"doc":"{:ok, featurizer} = Bumblebee.load_featurizer({:hf, \"microsoft/resnet-50\"})","ref":"Bumblebee.html#load_featurizer/2-examples","title":"Examples - Bumblebee.load_featurizer/2","type":"function"},{"doc":"Loads generation config from a model repository.\n\nGeneration config includes a number of model-specific properties,\nso it is usually best to load the config and further configure,\nrather than building from scratch.\n\nSee `Bumblebee.Text.GenerationConfig` for all the available options.","ref":"Bumblebee.html#load_generation_config/1","title":"Bumblebee.load_generation_config/1","type":"function"},{"doc":"{:ok, generation_config} = Bumblebee.load_generation_config({:hf, \"gpt2\"})\n\n    generation_config = Bumblebee.configure(generation_config, max_new_tokens: 10)","ref":"Bumblebee.html#load_generation_config/1-examples","title":"Examples - Bumblebee.load_generation_config/1","type":"function"},{"doc":"Loads a pre-trained model from a model repository.","ref":"Bumblebee.html#load_model/2","title":"Bumblebee.load_model/2","type":"function"},{"doc":"* `:spec` - the model specification to use when building the model.\n    By default the specification is loaded using `load_spec/2`\n\n  * `:module` - the model specification module. By default it is\n    inferred from the configuration file, if that is not possible,\n    it must be specified explicitly\n\n  * `:architecture` - the model architecture, must be supported by\n    `:module`. By default it is inferred from the configuration file\n\n  * `:params_filename` - the file with the model parameters to be loaded\n\n  * `:log_params_diff` - whether to log missing, mismatched and unused\n    parameters. By default diff is logged only if some parameters\n    cannot be loaded\n\n  * `:backend` - the backend to allocate the tensors on. It is either\n    an atom or a tuple in the shape `{backend, options}`","ref":"Bumblebee.html#load_model/2-options","title":"Options - Bumblebee.load_model/2","type":"function"},{"doc":"By default the model type is inferred from configuration, so loading\nis as simple as:\n\n    {:ok, resnet} = Bumblebee.load_model({:hf, \"microsoft/resnet-50\"})\n    %{model: model, params: params, spec: spec} = resnet\n\nYou can explicitly specify a different architecture, in which case\nmatching parameters are still loaded:\n\n    {:ok, resnet} = Bumblebee.load_model({:hf, \"microsoft/resnet-50\"}, architecture: :base)\n\nTo further customize the model, you can also pass the specification:\n\n    {:ok, spec} = Bumblebee.load_spec({:hf, \"microsoft/resnet-50\"})\n    spec = Bumblebee.configure(spec, num_labels: 10)\n    {:ok, resnet} = Bumblebee.load_model({:hf, \"microsoft/resnet-50\"}, spec: spec)","ref":"Bumblebee.html#load_model/2-examples","title":"Examples - Bumblebee.load_model/2","type":"function"},{"doc":"Loads scheduler from a model repository.","ref":"Bumblebee.html#load_scheduler/2","title":"Bumblebee.load_scheduler/2","type":"function"},{"doc":"* `:module` - the scheduler module. By default it is inferred\n    from the scheduler configuration file, if that is not possible,\n    it must be specified explicitly","ref":"Bumblebee.html#load_scheduler/2-options","title":"Options - Bumblebee.load_scheduler/2","type":"function"},{"doc":"{:ok, scheduler} =\n      Bumblebee.load_scheduler({:hf, \"CompVis/stable-diffusion-v1-4\", subdir: \"scheduler\"})","ref":"Bumblebee.html#load_scheduler/2-examples","title":"Examples - Bumblebee.load_scheduler/2","type":"function"},{"doc":"Loads model specification from a model repository.","ref":"Bumblebee.html#load_spec/2","title":"Bumblebee.load_spec/2","type":"function"},{"doc":"* `:module` - the model specification module. By default it is\n    inferred from the configuration file, if that is not possible,\n    it must be specified explicitly\n\n  * `:architecture` - the model architecture, must be supported by\n    `:module`. By default it is inferred from the configuration file","ref":"Bumblebee.html#load_spec/2-options","title":"Options - Bumblebee.load_spec/2","type":"function"},{"doc":"{:ok, spec} = Bumblebee.load_spec({:hf, \"microsoft/resnet-50\"})\n\nYou can explicitly specify a different architecture:\n\n    {:ok, spec} = Bumblebee.load_spec({:hf, \"microsoft/resnet-50\"}, architecture: :base)","ref":"Bumblebee.html#load_spec/2-examples","title":"Examples - Bumblebee.load_spec/2","type":"function"},{"doc":"Loads tokenizer from a model repository.","ref":"Bumblebee.html#load_tokenizer/2","title":"Bumblebee.load_tokenizer/2","type":"function"},{"doc":"* `:module` - the tokenizer module. By default it is inferred from\n    the configuration files, if that is not possible, it must be\n    specified explicitly","ref":"Bumblebee.html#load_tokenizer/2-options","title":"Options - Bumblebee.load_tokenizer/2","type":"function"},{"doc":"{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"bert-base-uncased\"})","ref":"Bumblebee.html#load_tokenizer/2-examples","title":"Examples - Bumblebee.load_tokenizer/2","type":"function"},{"doc":"Initializes state for a new scheduler loop.\n\nReturns a pair of `{state, timesteps}`, where `state` is an opaque\ncontainer expected by `scheduler_step/4` and `timesteps` is a sequence\nof subsequent timesteps for model forward pass.\n\nNote that the number of `timesteps` may not match `num_steps` exactly.\n`num_steps` parameterizes sampling points, however depending on the\nmethod, sampling certain points may require multiple forward passes\nof the model and each element in `timesteps` corresponds to a single\nforward pass.","ref":"Bumblebee.html#scheduler_init/3","title":"Bumblebee.scheduler_init/3","type":"function"},{"doc":"Predicts sample at the previous timestep using the given scheduler.\n\nTakes the current `sample` and `prediction` (usually noise) returned\nby the model at the current timestep. Returns `{state, prev_sample}`,\nwhere `state` is the updated scheduler loop state and `prev_sample`\nis the predicted sample at the previous timestep.\n\nNote that some schedulers require several forward passes of the model\n(and a couple calls to this function) to make an actual prediction for\nthe previous sample.","ref":"Bumblebee.html#scheduler_step/4","title":"Bumblebee.scheduler_step/4","type":"function"},{"doc":"A model together with its state and metadata.","ref":"Bumblebee.html#t:model_info/0","title":"Bumblebee.model_info/0","type":"type"},{"doc":"A location to fetch model files from.\n\nCan be either:\n\n  * `{:hf, repository_id}` - the repository on Hugging Face. Options\n    may be passed as the third element:\n\n      * `:revision` - the specific model version to use, it can be\n        any valid git identifier, such as branch name, tag name, or\n        a commit hash\n\n      * `:cache_dir` - the directory to store the downloaded files\n        in. Defaults to the standard cache location for the given\n        operating system. You can also configure it globally by\n        setting the `BUMBLEBEE_CACHE_DIR` environment variable\n\n      * `:offline` - if `true`, only cached files are accessed and\n        missing files result in an error. You can also configure it\n        globally by setting the `BUMBLEBEE_OFFLINE` environment\n        variable to `true`\n\n      * `:auth_token` - the token to use as HTTP bearer authorization\n        for remote files\n\n      * `:subdir` - the directory within the repository where the\n        files are located\n\n  * `{:local, directory}` - the directory containing model files","ref":"Bumblebee.html#t:repository/0","title":"Bumblebee.repository/0","type":"type"},{"doc":"High-level tasks related to audio processing.","ref":"Bumblebee.Audio.html","title":"Bumblebee.Audio","type":"module"},{"doc":"Builds serving for speech-to-text generation.\n\nThe serving accepts `t:speech_to_text_input/0` and returns\n`t:speech_to_text_output/0`. A list of inputs is also supported.","ref":"Bumblebee.Audio.html#speech_to_text/5","title":"Bumblebee.Audio.speech_to_text/5","type":"function"},{"doc":"* `:seed` - random seed to use when sampling. By default the current\n    timestamp is used\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Audio.html#speech_to_text/5-options","title":"Options - Bumblebee.Audio.speech_to_text/5","type":"function"},{"doc":"{:ok, whisper} = Bumblebee.load_model({:hf, \"openai/whisper-tiny\"})\n    {:ok, featurizer} = Bumblebee.load_featurizer({:hf, \"openai/whisper-tiny\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"openai/whisper-tiny\"})\n    {:ok, generation_config} = Bumblebee.load_generation_config({:hf, \"openai/whisper-tiny\"})\n\n    serving =\n      Bumblebee.Audio.speech_to_text(whisper, featurizer, tokenizer, generation_config,\n        defn_options: [compiler: EXLA]\n      )\n\n    Nx.Serving.run(serving, {:file, \"/path/to/audio.wav\"})\n    #=> %{results: [%{text: \"There is a cat outside the window.\"}]}","ref":"Bumblebee.Audio.html#speech_to_text/5-examples","title":"Examples - Bumblebee.Audio.speech_to_text/5","type":"function"},{"doc":"A term representing audio.\n\nCan be either of:\n\n  * a 1-dimensional `Nx.Tensor` with audio samples\n\n  * `{:file, path}` with path to an audio file (note that this\n    requires `ffmpeg` installed)","ref":"Bumblebee.Audio.html#t:speech_to_text_input/0","title":"Bumblebee.Audio.speech_to_text_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Audio.html#t:speech_to_text_output/0","title":"Bumblebee.Audio.speech_to_text_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Audio.html#t:speech_to_text_result/0","title":"Bumblebee.Audio.speech_to_text_result/0","type":"type"},{"doc":"High-level tasks based on Stable Diffusion.","ref":"Bumblebee.Diffusion.StableDiffusion.html","title":"Bumblebee.Diffusion.StableDiffusion","type":"module"},{"doc":"Build serving for prompt-driven image generation.\n\nThe serving accepts `t:text_to_image_input/0` and returns `t:text_to_image_output/0`.\nA list of inputs is also supported.\n\nYou can specify `:safety_checker` model to automatically detect\nwhen a generated image is offensive or harmful and filter it out.","ref":"Bumblebee.Diffusion.StableDiffusion.html#text_to_image/6","title":"Bumblebee.Diffusion.StableDiffusion.text_to_image/6","type":"function"},{"doc":"* `:safety_checker` - the safety checker model info map. When a\n    safety checker is used, each output entry has an additional\n    `:is_safe` property and unsafe images are automatically zeroed.\n    Make sure to also set `:safety_checker_featurizer`\n\n  * `:safety_checker_featurizer` - the featurizer to use to preprocess\n    the safety checker input images\n\n  * `:num_steps` - the number of denoising steps. More denoising\n    steps usually lead to higher image quality at the expense of\n    slower inference. Defaults to `50`\n\n  * `:num_images_per_prompt` - the number of images to generate for\n    each prompt. Defaults to `1`\n\n  * `:guidance_scale` - the scale used for classifier-free diffusion\n    guidance. Higher guidance scale makes the generated images more\n    closely reflect the text prompt. This parameter corresponds to\n    $\\omega$ in Equation (2) of the [Imagen paper](https://arxiv.org/pdf/2205.11487.pdf).\n    Defaults to `7.5`\n\n  * `:seed` - a seed for the random number generator. Defaults to `0`\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Diffusion.StableDiffusion.html#text_to_image/6-options","title":"Options - Bumblebee.Diffusion.StableDiffusion.text_to_image/6","type":"function"},{"doc":"repository_id = \"CompVis/stable-diffusion-v1-4\"\n\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"openai/clip-vit-large-patch14\"})\n\n    {:ok, clip} = Bumblebee.load_model({:hf, repository_id, subdir: \"text_encoder\"})\n\n    {:ok, unet} =\n      Bumblebee.load_model({:hf, repository_id, subdir: \"unet\"},\n        params_filename: \"diffusion_pytorch_model.bin\"\n      )\n\n    {:ok, vae} =\n      Bumblebee.load_model({:hf, repository_id, subdir: \"vae\"},\n        architecture: :decoder,\n        params_filename: \"diffusion_pytorch_model.bin\"\n      )\n\n    {:ok, scheduler} = Bumblebee.load_scheduler({:hf, repository_id, subdir: \"scheduler\"})\n    {:ok, featurizer} = Bumblebee.load_featurizer({:hf, repository_id, subdir: \"feature_extractor\"})\n    {:ok, safety_checker} = Bumblebee.load_model({:hf, repository_id, subdir: \"safety_checker\"})\n\n    serving =\n      Bumblebee.Diffusion.StableDiffusion.text_to_image(clip, unet, vae, tokenizer, scheduler,\n        num_steps: 20,\n        num_images_per_prompt: 2,\n        safety_checker: safety_checker,\n        safety_checker_featurizer: featurizer,\n        compile: [batch_size: 1, sequence_length: 60],\n        defn_options: [compiler: EXLA]\n      )\n\n    prompt = \"numbat in forest, detailed, digital art\"\n    Nx.Serving.run(serving, prompt)\n    #=> %{\n    #=>   results: [\n    #=>     %{\n    #=>       image: #Nx.Tensor ,\n    #=>       is_safe: true\n    #=>     },\n    #=>     %{\n    #=>       image: #Nx.Tensor ,\n    #=>       is_safe: true\n    #=>     }\n    #=>   ]\n    #=> }","ref":"Bumblebee.Diffusion.StableDiffusion.html#text_to_image/6-examples","title":"Examples - Bumblebee.Diffusion.StableDiffusion.text_to_image/6","type":"function"},{"doc":"","ref":"Bumblebee.Diffusion.StableDiffusion.html#t:text_to_image_input/0","title":"Bumblebee.Diffusion.StableDiffusion.text_to_image_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Diffusion.StableDiffusion.html#t:text_to_image_output/0","title":"Bumblebee.Diffusion.StableDiffusion.text_to_image_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Diffusion.StableDiffusion.html#t:text_to_image_result/0","title":"Bumblebee.Diffusion.StableDiffusion.text_to_image_result/0","type":"type"},{"doc":"High-level tasks related to text processing.","ref":"Bumblebee.Text.html","title":"Bumblebee.Text","type":"module"},{"doc":"Builds serving for conversational generation.\n\nThe serving accepts `t:conversation_input/0` and returns\n`t:conversation_output/0`. A list of inputs is also supported.\n\nEach call to serving returns the conversation history, which can be\nfed into the next run to maintain the context.\n\nNote that either `:max_new_tokens` or `:max_length` must be specified.","ref":"Bumblebee.Text.html#conversation/4","title":"Bumblebee.Text.conversation/4","type":"function"},{"doc":"* `:seed` - random seed to use when sampling. By default the current\n    timestamp is used\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length.\n        Note that in this case, the whole conversation history is the\n        input, so this value should be relatively large to allow long\n        history (though the supported upper limit depends on the model)\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Text.html#conversation/4-options","title":"Options - Bumblebee.Text.conversation/4","type":"function"},{"doc":"{:ok, model_info} = Bumblebee.load_model({:hf, \"facebook/blenderbot-400M-distill\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"facebook/blenderbot-400M-distill\"})\n\n    {:ok, generation_config} =\n      Bumblebee.load_generation_config({:hf, \"facebook/blenderbot-400M-distill\"})\n\n    serving = Bumblebee.Text.conversation(model_info, tokenizer, generation_config)\n\n    history = nil\n\n    message = \"Hey!\"\n    %{text: text, history: history} = Nx.Serving.run(serving, %{text: message, history: history})\n    #=> %{history: ..., text: \"Hey !\"}\n\n    message = \"What's up?\"\n    %{text: text, history: history} = Nx.Serving.run(serving, %{text: message, history: history})\n    #=> %{history: ..., text: \"Not much .\"}","ref":"Bumblebee.Text.html#conversation/4-examples","title":"Examples - Bumblebee.Text.conversation/4","type":"function"},{"doc":"Builds serving for the fill-mask task.\n\nThe serving accepts `t:fill_mask_input/0` and returns `t:fill_mask_output/0`.\nA list of inputs is also supported.\n\nIn the fill-mask task, the objective is to predict a masked word in\nthe text. The serving expects the input to have exactly one such word,\ndenoted as `[MASK]`.","ref":"Bumblebee.Text.html#fill_mask/3","title":"Bumblebee.Text.fill_mask/3","type":"function"},{"doc":"* `:top_k` - the number of top predictions to include in the output.\n    If the configured value is higher than the number of labels, all\n    labels are returned. Defaults to `5`\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Text.html#fill_mask/3-options","title":"Options - Bumblebee.Text.fill_mask/3","type":"function"},{"doc":"{:ok, bert} = Bumblebee.load_model({:hf, \"bert-base-uncased\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"bert-base-uncased\"})\n\n    serving = Bumblebee.Text.fill_mask(bert, tokenizer)\n\n    text = \"The capital of [MASK] is Paris.\"\n    Nx.Serving.run(serving, text)\n    #=> %{\n    #=>   predictions: [\n    #=>     %{score: 0.9279842972755432, token: \"france\"},\n    #=>     %{score: 0.008412551134824753, token: \"brittany\"},\n    #=>     %{score: 0.007433671969920397, token: \"algeria\"},\n    #=>     %{score: 0.004957548808306456, token: \"department\"},\n    #=>     %{score: 0.004369721747934818, token: \"reunion\"}\n    #=>   ]\n    #=> }","ref":"Bumblebee.Text.html#fill_mask/3-examples","title":"Examples - Bumblebee.Text.fill_mask/3","type":"function"},{"doc":"Builds serving for prompt-driven text generation.\n\nThe serving accepts `t:generation_input/0` and returns `t:generation_output/0`.\nA list of inputs is also supported.","ref":"Bumblebee.Text.html#generation/4","title":"Bumblebee.Text.generation/4","type":"function"},{"doc":"* `:seed` - random seed to use when sampling. By default the current\n    timestamp is used\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`\n\n  * `:stream` - when `true`, the serving immediately returns a\n    stream that emits text chunks as they are generated. Note that\n    when using streaming, only a single input can be given to the\n    serving. To process a batch, call the serving with each input\n    separately. Defaults to `false`","ref":"Bumblebee.Text.html#generation/4-options","title":"Options - Bumblebee.Text.generation/4","type":"function"},{"doc":"{:ok, model_info} = Bumblebee.load_model({:hf, \"gpt2\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"gpt2\"})\n    {:ok, generation_config} = Bumblebee.load_generation_config({:hf, \"gpt2\"})\n    generation_config = Bumblebee.configure(generation_config, max_new_tokens: 15)\n\n    serving = Bumblebee.Text.generation(model_info, tokenizer, generation_config)\n\n    Nx.Serving.run(serving, \"Elixir is a functional\")\n    #=> %{\n    #=>   results: [\n    #=>     %{\n    #=>       text: \"Elixir is a functional programming language that is designed to be used in a variety of applications. It\"\n    #=>     }\n    #=>   ]\n    #=> }\n\nWe can stream the result by creating the serving with `stream: true`:\n\n    {:ok, model_info} = Bumblebee.load_model({:hf, \"gpt2\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"gpt2\"})\n    {:ok, generation_config} = Bumblebee.load_generation_config({:hf, \"gpt2\"})\n    generation_config = Bumblebee.configure(generation_config, max_new_tokens: 15)\n\n    serving = Bumblebee.Text.generation(model_info, tokenizer, generation_config, stream: true)\n\n    Nx.Serving.run(serving, \"Elixir is a functional\") |> Enum.to_list()\n    #=> [\" programming\", \" language\", \" that\", \" is\", \" designed\", \" to\", \" be\", \" used\", \" in\", \" a\",\n    #=>  \" variety\", \" of\", \" applications.\", \" It\"]","ref":"Bumblebee.Text.html#generation/4-examples","title":"Examples - Bumblebee.Text.generation/4","type":"function"},{"doc":"Builds serving for the question answering task.\n\nThe serving accepts `t:question_answering_input/0` and returns\n`t:question_answering_output/0`. A list of inputs is also supported.\n\nThe question answering task finds the most probable answer to a\nquestion within the given context text.","ref":"Bumblebee.Text.html#question_answering/3","title":"Bumblebee.Text.question_answering/3","type":"function"},{"doc":"* `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size. Note\n        that the batch size refers to the number of prompts to classify,\n        while the model prediction is made for every combination of\n        prompt and label\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Text.html#question_answering/3-options","title":"Options - Bumblebee.Text.question_answering/3","type":"function"},{"doc":"{:ok, roberta} = Bumblebee.load_model({:hf, \"deepset/roberta-base-squad2\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"roberta-base\"})\n\n    serving = Bumblebee.Text.question_answering(roberta, tokenizer)\n\n    input = %{question: \"What's my name?\", context: \"My name is Sarah and I live in London.\"}\n    Nx.Serving.run(serving, input)\n    #=> %{results: [%{end: 16, score: 0.81039959192276, start: 11, text: \"Sarah\"}]}","ref":"Bumblebee.Text.html#question_answering/3-examples","title":"Examples - Bumblebee.Text.question_answering/3","type":"function"},{"doc":"Builds serving for text classification.\n\nThe serving accepts `t:text_classification_input/0` and returns\n`t:text_classification_output/0`. A list of inputs is also supported.","ref":"Bumblebee.Text.html#text_classification/3","title":"Bumblebee.Text.text_classification/3","type":"function"},{"doc":"* `:top_k` - the number of top predictions to include in the output. If\n    the configured value is higher than the number of labels, all\n    labels are returned. Defaults to `5`\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:scores_function` - the function to use for converting logits to\n    scores. Should be one of `:softmax`, `:sigmoid`, or `:none`.\n    Defaults to `:softmax`\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Text.html#text_classification/3-options","title":"Options - Bumblebee.Text.text_classification/3","type":"function"},{"doc":"{:ok, bertweet} = Bumblebee.load_model({:hf, \"finiteautomata/bertweet-base-sentiment-analysis\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"vinai/bertweet-base\"})\n\n    serving = Bumblebee.Text.text_classification(bertweet, tokenizer)\n\n    text = \"Cats are cute.\"\n    Nx.Serving.run(serving, text)\n    #=> %{\n    #=>   predictions: [\n    #=>     %{label: \"POS\", score: 0.9876555800437927},\n    #=>     %{label: \"NEU\", score: 0.010068908333778381},\n    #=>     %{label: \"NEG\", score: 0.002275536535307765}\n    #=>   ]\n    #=> }","ref":"Bumblebee.Text.html#text_classification/3-examples","title":"Examples - Bumblebee.Text.text_classification/3","type":"function"},{"doc":"Builds serving for text embeddings.\n\nThe serving accepts `t:text_embedding_input/0` and returns\n`t:text_embedding_output/0`. A list of inputs is also supported.","ref":"Bumblebee.Text.html#text_embedding/3","title":"Bumblebee.Text.text_embedding/3","type":"function"},{"doc":"* `:output_attribute` - the attribute of the model output map to\n    retrieve. When the output is a single tensor (rather than a map),\n    this option is ignored. Defaults to `:pooled_state`\n\n  * `:output_pool` - pooling to apply on top of the model output, in case\n    it is not already a pooled embedding. Supported values: `:mean`. By\n    default no pooling is applied\n\n  * `:embedding_processor` - a post-processing step to apply to the\n    embedding. Supported values: `:l2_norm`. By default the output is\n    returned as is\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Text.html#text_embedding/3-options","title":"Options - Bumblebee.Text.text_embedding/3","type":"function"},{"doc":"{:ok, model_info} = Bumblebee.load_model({:hf, \"intfloat/e5-large\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"intfloat/e5-large\"})\n\n    serving = Bumblebee.Text.TextEmbedding.text_embedding(model_info, tokenizer)\n\n    text = \"query: Cats are cute.\"\n    Nx.Serving.run(serving, text)\n\n    #=> %{\n    #=>   embedding: #Nx.Tensor \n    #=>     [-0.9789889454841614, -0.9814645051956177, -0.5015208125114441, 0.9867952466011047, 0.9917466640472412, -0.5557178258895874, -0.18618212640285492, 0.797040581703186, 0.8922086954116821, 0.7599573135375977, -0.16524426639080048, -0.8740050792694092, 0.9433475732803345, 0.7217797636985779, 0.9437620639801025, 0.4694959223270416, 0.40594056248664856, -0.20143413543701172, 0.7144518494606018, -0.8689796924591064, 0.94001305103302, 0.17163503170013428, -0.9896315932273865, 0.4455447494983673, 0.41139301657676697, 0.01911175064742565, -0.11275406181812286, -0.734498143196106, -0.6410953402519226, -0.628239095211029, -0.2570168673992157, 0.475137323141098, -0.7534396052360535, -0.9492156505584717, -0.17271563410758972, 0.9081271886825562, -0.4851466119289398, -0.9440935254096985, -0.20976334810256958, -0.684502899646759, -0.11581139266490936, 0.17509342730045319, 0.05547652021050453, 0.31042391061782837, 0.955132007598877, -0.35595986247062683, 0.016105204820632935, -0.3154579997062683, 0.9630348682403564, ...]\n    #=>   >\n    #=> }","ref":"Bumblebee.Text.html#text_embedding/3-examples","title":"Examples - Bumblebee.Text.text_embedding/3","type":"function"},{"doc":"Builds serving for token classification.\n\nThe serving accepts `t:token_classification_input/0` and returns\n`t:token_classification_output/0`. A list of inputs is also supported.\n\nThis function can be used for tasks such as named entity recognition\n(NER) or part of speech tagging (POS).\n\nThe recognized entities can optionally be aggregated into groups\nbased on the given strategy.","ref":"Bumblebee.Text.html#token_classification/3","title":"Bumblebee.Text.token_classification/3","type":"function"},{"doc":"* `:aggregation` - an optional strategy for aggregating adjacent\n    tokens. Token classification models output probabilities for\n    each possible token class. The aggregation strategy takes scores\n    for each token (which possibly represents subwords) and groups\n    tokens into phrases which are readily interpretable as entities\n    of a certain class. Supported aggregation strategies:\n\n      * `nil` (default) - corresponds to no aggregation and returns\n        the most likely label for each input token\n\n      * `:same` - groups adjacent tokens with the same label. If\n        the labels use beginning-inside-outside (BIO) tagging, the\n        boundaries are respected and the prefix is omitted in the\n        output labels\n\n      * `:word_first` - uses `:same` strategy except that word tokens\n        cannot end up with different labels. With this strategy word\n        gets the label of the first token of that word when there\n        is ambiguity. Note that this works only on word based models\n\n      * `:word_average` - uses `:same` strategy except that word tokens\n        cannot end up with different labels. With this strategy scores\n        are averaged across word tokens and then the maximum label\n        is taken. Note that this works only on word based models\n\n      * `:word_max` - uses `:same` strategy except that word tokens\n        cannot end up with different labels. With this strategy word\n        gets the label of the token with the maximum score. Note that\n        this works only on word based models\n\n  * `:ignored_labels` - the labels to ignore in the final output.\n    The labels should be specified without BIO prefix. Defaults to\n    `[\"O\"]`\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:scores_function` - the function to use for converting logits to\n    scores. Should be one of `:softmax`, `:sigmoid`, or `:none`.\n    Defaults to `:softmax`\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Text.html#token_classification/3-options","title":"Options - Bumblebee.Text.token_classification/3","type":"function"},{"doc":"{:ok, bert} = Bumblebee.load_model({:hf, \"dslim/bert-base-NER\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"bert-base-cased\"})\n\n    serving = Bumblebee.Text.token_classification(bert, tokenizer, aggregation: :same)\n\n    text = \"Rachel Green works at Ralph Lauren in New York City in the sitcom Friends\"\n    Nx.Serving.run(serving, text)\n    #=> %{\n    #=>  entities: [\n    #=>    %{end: 12, label: \"PER\", phrase: \"Rachel Green\", score: 0.9997024834156036, start: 0},\n    #=>    %{end: 34, label: \"ORG\", phrase: \"Ralph Lauren\", score: 0.9968731701374054, start: 22},\n    #=>    %{end: 51, label: \"LOC\", phrase: \"New York City\", score: 0.9995547334353129, start: 38},\n    #=>    %{end: 73, label: \"MISC\", phrase: \"Friends\", score: 0.6997143030166626, start: 66}\n    #=>  ]\n    #=>}","ref":"Bumblebee.Text.html#token_classification/3-examples","title":"Examples - Bumblebee.Text.token_classification/3","type":"function"},{"doc":"Builds serving for the zero-shot classification task.\n\nThe serving accepts `t:zero_shot_classification_input/0` and returns\n`t:zero_shot_classification_output/0`. A list of inputs is also\nsupported.\n\nThe zero-shot task predicts zero-shot labels for a given sequence by\nproposing each label as a premise-hypothesis pairing.","ref":"Bumblebee.Text.html#zero_shot_classification/4","title":"Bumblebee.Text.zero_shot_classification/4","type":"function"},{"doc":"* `:top_k` - the number of top predictions to include in the output. If\n    the configured value is higher than the number of labels, all\n    labels are returned. Defaults to `5`\n\n  * `:hypothesis_template` - an arity-1 function which accepts a label\n    and returns a hypothesis. The default hypothesis format is: \"This example\n    is #{label}\".\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size. Note\n        that the batch size refers to the number of prompts to classify,\n        while the model prediction is made for every combination of\n        prompt and label\n\n      * `:sequence_length` - the maximum input sequence length. Input\n        sequences are always padded/truncated to match that length.\n        A list can be given, in which case the serving compiles\n        a separate computation for each length and then inputs are\n        matched to the smallest bounding length\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Text.html#zero_shot_classification/4-options","title":"Options - Bumblebee.Text.zero_shot_classification/4","type":"function"},{"doc":"{:ok, model} = Bumblebee.load_model({:hf, \"facebook/bart-large-mnli\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"facebook/bart-large-mnli\"})\n\n    labels = [\"cooking\", \"traveling\", \"dancing\"]\n    zero_shot_serving = Bumblebee.Text.zero_shot_classification(model, tokenizer, labels)\n\n    output = Nx.Serving.run(zero_shot_serving, \"One day I will see the world\")\n    #=> %{\n    #=>   predictions: [\n    #=>     %{label: \"cooking\", score: 0.0070497458800673485},\n    #=>     %{label: \"traveling\", score: 0.985000491142273},\n    #=>     %{label: \"dancing\", score: 0.007949736900627613}\n    #=>   ]\n    #=> }","ref":"Bumblebee.Text.html#zero_shot_classification/4-examples","title":"Examples - Bumblebee.Text.zero_shot_classification/4","type":"function"},{"doc":"","ref":"Bumblebee.Text.html#t:conversation_history/0","title":"Bumblebee.Text.conversation_history/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:conversation_input/0","title":"Bumblebee.Text.conversation_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:conversation_output/0","title":"Bumblebee.Text.conversation_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:fill_mask_input/0","title":"Bumblebee.Text.fill_mask_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:fill_mask_output/0","title":"Bumblebee.Text.fill_mask_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:fill_mask_prediction/0","title":"Bumblebee.Text.fill_mask_prediction/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:generation_input/0","title":"Bumblebee.Text.generation_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:generation_output/0","title":"Bumblebee.Text.generation_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:generation_result/0","title":"Bumblebee.Text.generation_result/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:question_answering_input/0","title":"Bumblebee.Text.question_answering_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:question_answering_output/0","title":"Bumblebee.Text.question_answering_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:question_answering_result/0","title":"Bumblebee.Text.question_answering_result/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:text_classification_input/0","title":"Bumblebee.Text.text_classification_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:text_classification_output/0","title":"Bumblebee.Text.text_classification_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:text_classification_prediction/0","title":"Bumblebee.Text.text_classification_prediction/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:text_embedding_input/0","title":"Bumblebee.Text.text_embedding_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:text_embedding_output/0","title":"Bumblebee.Text.text_embedding_output/0","type":"type"},{"doc":"A single entity label.\n\nNote that `start` and `end` indices are expressed in terms of UTF-8\nbytes.","ref":"Bumblebee.Text.html#t:token_classification_entity/0","title":"Bumblebee.Text.token_classification_entity/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:token_classification_input/0","title":"Bumblebee.Text.token_classification_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:token_classification_output/0","title":"Bumblebee.Text.token_classification_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:zero_shot_classification_input/0","title":"Bumblebee.Text.zero_shot_classification_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:zero_shot_classification_output/0","title":"Bumblebee.Text.zero_shot_classification_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Text.html#t:zero_shot_classification_prediction/0","title":"Bumblebee.Text.zero_shot_classification_prediction/0","type":"type"},{"doc":"High-level tasks related to vision.","ref":"Bumblebee.Vision.html","title":"Bumblebee.Vision","type":"module"},{"doc":"Builds serving for image classification.\n\nThe serving accepts `t:image_classification_input/0` and returns\n`t:image_classification_output/0`. A list of inputs is also supported.","ref":"Bumblebee.Vision.html#image_classification/3","title":"Bumblebee.Vision.image_classification/3","type":"function"},{"doc":"* `:top_k` - the number of top predictions to include in the output. If\n    the configured value is higher than the number of labels, all\n    labels are returned. Defaults to `5`\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:scores_function` - the function to use for converting logits to\n    scores. Should be one of `:softmax`, `:sigmoid`, or `:none`.\n    Defaults to `:softmax`\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Vision.html#image_classification/3-options","title":"Options - Bumblebee.Vision.image_classification/3","type":"function"},{"doc":"{:ok, resnet} = Bumblebee.load_model({:hf, \"microsoft/resnet-50\"})\n    {:ok, featurizer} = Bumblebee.load_featurizer({:hf, \"microsoft/resnet-50\"})\n\n    serving = Bumblebee.Vision.image_classification(resnet, featurizer)\n\n    image = StbImage.read_file!(path)\n    Nx.Serving.run(serving, image)\n    #=> %{\n    #=>   predictions: [\n    #=>     %{label: \"Egyptian cat\", score: 0.979233980178833},\n    #=>     %{label: \"tabby, tabby cat\", score: 0.00679466687142849},\n    #=>     %{label: \"tiger cat\", score: 0.005290505941957235},\n    #=>     %{label: \"lynx, catamount\", score: 0.004550771787762642},\n    #=>     %{label: \"Siamese cat, Siamese\", score: 1.1611092486418784e-4}\n    #=>   ]\n    #=> }","ref":"Bumblebee.Vision.html#image_classification/3-examples","title":"Examples - Bumblebee.Vision.image_classification/3","type":"function"},{"doc":"Builds serving for image embeddings.\n\nThe serving accepts `t:image_embedding_input/0` and returns\n`t:image_embedding_output/0`. A list of inputs is also supported.","ref":"Bumblebee.Vision.html#image_embedding/3","title":"Bumblebee.Vision.image_embedding/3","type":"function"},{"doc":"* `:output_attribute` - the attribute of the model output map to\n    retrieve. When the output is a single tensor (rather than a map),\n    this option is ignored. Defaults to `:pooled_state`\n\n  * `:embedding_processor` - a post-processing step to apply to the\n    embedding. Supported values: `:l2_norm`. By default the output is\n    returned as is\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Vision.html#image_embedding/3-options","title":"Options - Bumblebee.Vision.image_embedding/3","type":"function"},{"doc":"{:ok, clip} =\n      Bumblebee.load_model({:hf, \"openai/clip-vit-base-patch32\"},\n        module: Bumblebee.Vision.ClipVision\n      )\n    {:ok, featurizer} = Bumblebee.load_featurizer({:hf, \"openai/clip-vit-base-patch32\"})\n    serving = Bumblebee.Vision.ImageEmbedding.image_embedding(clip, featurizer)\n    image = StbImage.read_file!(path)\n    Nx.Serving.run(serving, image)\n    #=> %{\n    #=>   embedding: #Nx.Tensor \n    #=> }","ref":"Bumblebee.Vision.html#image_embedding/3-examples","title":"Examples - Bumblebee.Vision.image_embedding/3","type":"function"},{"doc":"Builds serving for image-to-text generation.\n\nThe serving accepts `t:image_to_text_input/0` and returns\n`t:image_to_text_output/0`. A list of inputs is also supported.","ref":"Bumblebee.Vision.html#image_to_text/5","title":"Bumblebee.Vision.image_to_text/5","type":"function"},{"doc":"* `:seed` - random seed to use when sampling. By default the current\n    timestamp is used\n\n  * `:compile` - compiles all computations for predefined input shapes\n    during serving initialization. Should be a keyword list with the\n    following keys:\n\n      * `:batch_size` - the maximum batch size of the input. Inputs\n        are optionally padded to always match this batch size\n\n    It is advised to set this option in production and also configure\n    a defn compiler using `:defn_options` to maximally reduce inference\n    time.\n\n  * `:defn_options` - the options for JIT compilation. Defaults to `[]`\n\n  * `:preallocate_params` - when `true`, explicitly allocates params\n    on the device configured by `:defn_options`. You may want to set\n    this option when using partitioned serving, to allocate params\n    on each of the devices. Defaults to `false`","ref":"Bumblebee.Vision.html#image_to_text/5-options","title":"Options - Bumblebee.Vision.image_to_text/5","type":"function"},{"doc":"{:ok, blip} = Bumblebee.load_model({:hf, \"Salesforce/blip-image-captioning-base\"})\n    {:ok, featurizer} = Bumblebee.load_featurizer({:hf, \"Salesforce/blip-image-captioning-base\"})\n    {:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"Salesforce/blip-image-captioning-base\"})\n\n    {:ok, generation_config} =\n      Bumblebee.load_generation_config({:hf, \"Salesforce/blip-image-captioning-base\"})\n\n    serving =\n      Bumblebee.Vision.image_to_text(blip, featurizer, tokenizer, generation_config,\n        defn_options: [compiler: EXLA]\n      )\n\n    image = StbImage.read_file!(path)\n    Nx.Serving.run(serving, image)\n    #=> %{results: [%{text: \"a cat sitting on a chair\"}]}","ref":"Bumblebee.Vision.html#image_to_text/5-examples","title":"Examples - Bumblebee.Vision.image_to_text/5","type":"function"},{"doc":"A term representing an image.\n\nEither `Nx.Tensor` or a struct implementing `Nx.Container` and\nresolving to a tensor, with the following properties:\n\n  * HWC order\n  * RGB color channels\n  * alpha channel may be present, but it's usually stripped out\n  * integer type (`:s` or `:u`)","ref":"Bumblebee.Vision.html#t:image/0","title":"Bumblebee.Vision.image/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_classification_input/0","title":"Bumblebee.Vision.image_classification_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_classification_output/0","title":"Bumblebee.Vision.image_classification_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_classification_prediction/0","title":"Bumblebee.Vision.image_classification_prediction/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_embedding_input/0","title":"Bumblebee.Vision.image_embedding_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_embedding_output/0","title":"Bumblebee.Vision.image_embedding_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_to_text_input/0","title":"Bumblebee.Vision.image_to_text_input/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_to_text_output/0","title":"Bumblebee.Vision.image_to_text_output/0","type":"type"},{"doc":"","ref":"Bumblebee.Vision.html#t:image_to_text_result/0","title":"Bumblebee.Vision.image_to_text_result/0","type":"type"},{"doc":"Whisper model family.","ref":"Bumblebee.Audio.Whisper.html","title":"Bumblebee.Audio.Whisper","type":"module"},{"doc":"* `:base` - plain Whisper without any head on top\n\n  * `:for_conditional_generation` - Whisper with a language modeling\n    head. The head returns logits for each token in the original\n    sequence","ref":"Bumblebee.Audio.Whisper.html#module-architectures","title":"Architectures - Bumblebee.Audio.Whisper","type":"module"},{"doc":"* `\"input_features\"` - `{batch_size, input_length, feature_size}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_features\"`, which can be specified\n    for more control over how `\"input_features\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_features\"` will be ignored.\n\n  * `\"decoder_input_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of decoder input sequence tokens in the vocabulary.\n\n  * `\"decoder_attention_mask\"` - `{batch_size, target_sequence_length}`\n\n    Mask indicating which decoder tokens to attend to. This is used\n    to ignore padding tokens, which are added when processing a batch\n    of sequences with different length.\n\n  * `\"decoder_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the decoder.\n\n  * `\"decoder_input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"decoder_input_ids\"`, which can be\n    specified for more control over how `\"decoder_input_ids\"` are\n    embedded than the model's internal embedding lookup. If\n    `\"decoder_input_embeddings\"` are present, then `\"decoder_input_ids\"`\n    will be ignored.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Last hidden state output from the encoder. This hidden state is\n    used in cross-attention blocks in the decoder. If specified, the\n    model will skip the encoding process and use this value directly\n    for cross-attentions in the decoder.\n\n  * `\"cross_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the cross-attention blocks in\n    the decoder with shape.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Audio.Whisper.html#module-inputs","title":"Inputs - Bumblebee.Audio.Whisper","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the model. This corresponds to the number of distinct\n    tokens that can be represented by the decoder\n    . Defaults to `51865`\n\n  * `:feature_size` - the dimensionality of the input features. This corresponds to the number of Mel\n    bins in the preprocessed input\n    . Defaults to `80`\n\n  * `:encoder_max_positions` - the vocabulary size of the encoder position embedding. This corresponds to the maximum\n    sequence length of log-mel filter-bank features that the model can process\n    . Defaults to `1500`\n\n  * `:decoder_max_positions` - the vocabulary size of the decoder position embedding. This corresponds to the maximum\n    sequence length that this model can generate. Typically this is set to a large value just\n    in case, such as 512, 1024 or 2048\n    . Defaults to `448`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `1024`\n\n  * `:encoder_num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:decoder_num_blocks` - the number of Transformer blocks in the decoder. Defaults to `12`\n\n  * `:encoder_num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `16`\n\n  * `:decoder_num_attention_heads` - the number of attention heads for each attention layer in the decoder. Defaults to `16`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for encoder and decoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:activation_dropout_rate` - the dropout rate for activations inside fully connected layers. Defaults to `0.0`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`","ref":"Bumblebee.Audio.Whisper.html#module-configuration","title":"Configuration - Bumblebee.Audio.Whisper","type":"module"},{"doc":"A CLIP-based model for detecting unsafe image content.\n\nThis model is designed primarily to check images generated using\nStable Diffusion.","ref":"Bumblebee.Diffusion.StableDiffusion.SafetyChecker.html","title":"Bumblebee.Diffusion.StableDiffusion.SafetyChecker","type":"module"},{"doc":"* `:base` - the base safety detection model","ref":"Bumblebee.Diffusion.StableDiffusion.SafetyChecker.html#module-architectures","title":"Architectures - Bumblebee.Diffusion.StableDiffusion.SafetyChecker","type":"module"},{"doc":"* `\"pixel_values\"` - `{batch_size, image_size, image_size, num_channels}`\n\n    Featurized image pixel values.","ref":"Bumblebee.Diffusion.StableDiffusion.SafetyChecker.html#module-inputs","title":"Inputs - Bumblebee.Diffusion.StableDiffusion.SafetyChecker","type":"module"},{"doc":"* `:clip_spec` - the specification of the CLIP model. See `Bumblebee.Multimodal.Clip` for details","ref":"Bumblebee.Diffusion.StableDiffusion.SafetyChecker.html#module-configuration","title":"Configuration - Bumblebee.Diffusion.StableDiffusion.SafetyChecker","type":"module"},{"doc":"* [CompVis/stable-diffusion-v1-4](https://huggingface.co/CompVis/stable-diffusion-v1-4#safety-module)","ref":"Bumblebee.Diffusion.StableDiffusion.SafetyChecker.html#module-references","title":"References - Bumblebee.Diffusion.StableDiffusion.SafetyChecker","type":"module"},{"doc":"U-Net model with two spatial dimensions and conditional state.","ref":"Bumblebee.Diffusion.UNet2DConditional.html","title":"Bumblebee.Diffusion.UNet2DConditional","type":"module"},{"doc":"* `:base` - the U-Net model","ref":"Bumblebee.Diffusion.UNet2DConditional.html#module-architectures","title":"Architectures - Bumblebee.Diffusion.UNet2DConditional","type":"module"},{"doc":"* `\"sample\"` - `{batch_size, sample_size, sample_size, in_channels}`\n\n    Sample input with two spatial dimensions.\n\n  * `\"timestep\"` - `{}`\n\n    The timestep used to parameterize model behaviour in a multi-step\n    process, such as diffusion.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, sequence_length, hidden_size}`\n\n    The conditional state (context) to use with cross-attention.","ref":"Bumblebee.Diffusion.UNet2DConditional.html#module-inputs","title":"Inputs - Bumblebee.Diffusion.UNet2DConditional","type":"module"},{"doc":"* `:sample_size` - the size of the input spatial dimensions. Defaults to `32`\n\n  * `:in_channels` - the number of channels in the input. Defaults to `4`\n\n  * `:out_channels` - the number of channels in the output. Defaults to `4`\n\n  * `:center_input_sample` - whether to center the input sample. Defaults to `false`\n\n  * `:embedding_flip_sin_to_cos` - whether to flip the sin to cos in the sinusoidal timestep embedding. Defaults to `true`\n\n  * `:embedding_frequency_correction_term` - controls the frequency formula in the timestep sinusoidal embedding. The frequency is computed\n    as $\\\\omega_i = \\\\frac{1}{10000^{\\\\frac{i}{n - s}}}$, for $i \\\\in \\\\{0, ..., n-1\\\\}$, where $n$\n    is half of the embedding size and $s$ is the shift. Historically, certain implementations of\n    sinusoidal embedding used $s=0$, while others used $s=1$\n    . Defaults to `0`\n\n  * `:hidden_sizes` - the dimensionality of hidden layers in each upsample/downsample block. Defaults to `[320, 640, 1280, 1280]`\n\n  * `:depth` - the number of residual blocks in each upsample/downsample block. Defaults to `2`\n\n  * `:down_block_types` - a list of downsample block types. The supported blocks are: `:down_block`, `:cross_attention_down_block`. Defaults to `[:cross_attention_down_block, :cross_attention_down_block, :cross_attention_down_block, :down_block]`\n\n  * `:up_block_types` - a list of upsample block types. The supported blocks are: `:up_block`, `:cross_attention_up_block`. Defaults to `[:up_block, :cross_attention_up_block, :cross_attention_up_block, :cross_attention_up_block]`\n\n  * `:downsample_padding` - the padding to use in the downsample convolution. Defaults to `[{1, 1}, {1, 1}]`\n\n  * `:mid_block_scale_factor` - the scale factor to use for the mid block. Defaults to `1`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer. Optionally can be a list with one number per block. Defaults to `8`\n\n  * `:cross_attention_size` - the dimensionality of the cross attention features. Defaults to `1280`\n\n  * `:use_linear_projection` - whether the input/output projection of the transformer block should be linear or convolutional. Defaults to `false`\n\n  * `:activation` - the activation function. Defaults to `:silu`\n\n  * `:group_norm_num_groups` - the number of groups used by the group normalization layers. Defaults to `32`\n\n  * `:group_norm_epsilon` - the epsilon used by the group normalization layers. Defaults to `1.0e-5`","ref":"Bumblebee.Diffusion.UNet2DConditional.html#module-configuration","title":"Configuration - Bumblebee.Diffusion.UNet2DConditional","type":"module"},{"doc":"Variational autoencoder (VAE) with Kullback–Leibler divergence (KL) loss.","ref":"Bumblebee.Diffusion.VaeKl.html","title":"Bumblebee.Diffusion.VaeKl","type":"module"},{"doc":"* `:base` - the entire VAE model\n\n  * `:encoder` - just the encoder part of the base model\n\n  * `:decoder` - just the decoder part of the base model","ref":"Bumblebee.Diffusion.VaeKl.html#module-architectures","title":"Architectures - Bumblebee.Diffusion.VaeKl","type":"module"},{"doc":"* `\"sample\"` - `{batch_size, sample_size, sample_size, in_channels}`\n\n    Sample input with two spatial dimensions. Note that in case of\n    the `:decoder` model, the input usually has lower dimensionality.\n\n  * `\"sample_posterior\"` - `{}`\n\n    When `true`, the decoder input is sampled from the encoder output\n    distribution. Otherwise the distribution mode value is used instead.\n    This input is only relevant for the `:base` model. Defaults to `false`.","ref":"Bumblebee.Diffusion.VaeKl.html#module-inputs","title":"Inputs - Bumblebee.Diffusion.VaeKl","type":"module"},{"doc":"* `:sample_size` - the size of the input spatial dimensions. Defaults to `32`\n\n  * `:in_channels` - the number of channels in the input. Defaults to `3`\n\n  * `:out_channels` - the number of channels in the output. Defaults to `3`\n\n  * `:latent_channels` - the number of channels in the latent space. Defaults to `4`\n\n  * `:hidden_sizes` - the dimensionality of hidden layers in each upsample/downsample block. Defaults to `~c\"@\"`\n\n  * `:depth` - the number of residual blocks in each upsample/downsample block. Defaults to `1`\n\n  * `:down_block_types` - a list of downsample block types. Currently the only supported type is `:down_block`. Defaults to `[:down_block]`\n\n  * `:up_block_types` - a list of upsample block types. Currently the only supported type is `:up_block`. Defaults to `[:up_block]`\n\n  * `:activation` - the activation function. Defaults to `:silu`","ref":"Bumblebee.Diffusion.VaeKl.html#module-configuration","title":"Configuration - Bumblebee.Diffusion.VaeKl","type":"module"},{"doc":"* [Auto-Encoding Variational Bayes](https://arxiv.org/abs/1312.6114)","ref":"Bumblebee.Diffusion.VaeKl.html#module-references","title":"References - Bumblebee.Diffusion.VaeKl","type":"module"},{"doc":"The BLIP model for text-image similarity.","ref":"Bumblebee.Multimodal.Blip.html","title":"Bumblebee.Multimodal.Blip","type":"module"},{"doc":"* `:for_conditional_generation` - BLIP model with a language\n    modeling head","ref":"Bumblebee.Multimodal.Blip.html#module-architectures","title":"Architectures - Bumblebee.Multimodal.Blip","type":"module"},{"doc":"* `\"pixel_values\"` - `{batch_size, image_size, image_size, num_channels}`\n\n    Featurized image pixel values.\n\n  * `\"decoder_input_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of decoder input sequence tokens in the vocabulary. If not\n    present and `\"input_ids\"` is, it will be generated by shifting\n    each token in `\"input_ids\"` to the right once.\n\n  * `\"decoder_attention_mask\"` - `{batch_size, target_sequence_length}`\n\n    Mask indicating which decoder tokens to attend to. This is used\n    to ignore padding tokens, which are added when processing a batch\n    of sequences with different length.\n\n  * `\"decoder_position_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of positions of each decoder input sequence tokens in\n    the position embeddings.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Multimodal.Blip.html#module-inputs","title":"Inputs - Bumblebee.Multimodal.Blip","type":"module"},{"doc":"* `:text_spec` - the specification of the text model. See `Bumblebee.Text.BlipText` for details\n\n  * `:vision_spec` - the specification of the vision model. See `Bumblebee.Vision.BlipVision` for details\n\n  * `:projection_size` - the dimensionality of text and vision projection layers. Defaults to `512`\n\n  * `:logit_scale_initial_value` - the initial value for the scaling layer used to scale similarity logits. Defaults to `2.6592`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`","ref":"Bumblebee.Multimodal.Blip.html#module-configuration","title":"Configuration - Bumblebee.Multimodal.Blip","type":"module"},{"doc":"* [BLIP: Bootstrapping Language-Image Pre-training for Unified Vision-Language Understanding and Generation](https://arxiv.org/abs/2201.12086)","ref":"Bumblebee.Multimodal.Blip.html#module-references","title":"References - Bumblebee.Multimodal.Blip","type":"module"},{"doc":"The CLIP model for text-image similarity.","ref":"Bumblebee.Multimodal.Clip.html","title":"Bumblebee.Multimodal.Clip","type":"module"},{"doc":"* `:base` - the base CLIP model","ref":"Bumblebee.Multimodal.Clip.html#module-architectures","title":"Architectures - Bumblebee.Multimodal.Clip","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"pixel_values\"` - `{batch_size, image_size, image_size, num_channels}`\n\n    Featurized image pixel values.","ref":"Bumblebee.Multimodal.Clip.html#module-inputs","title":"Inputs - Bumblebee.Multimodal.Clip","type":"module"},{"doc":"* `:text_spec` - the specification of the text model. See `Bumblebee.Text.ClipText` for details\n\n  * `:vision_spec` - the specification of the vision model. See `Bumblebee.Vision.ClipVision` for details\n\n  * `:projection_size` - the dimensionality of text and vision projection layers. Defaults to `512`\n\n  * `:logit_scale_initial_value` - the initial value for the scaling layer used to scale similarity logits. Defaults to `2.6592`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`","ref":"Bumblebee.Multimodal.Clip.html#module-configuration","title":"Configuration - Bumblebee.Multimodal.Clip","type":"module"},{"doc":"* [CLIP: Connecting Text and Images](https://openai.com/blog/clip)\n\n  * [Learning Transferable Visual Models From Natural Language Supervision](https://arxiv.org/abs/2103.00020)","ref":"Bumblebee.Multimodal.Clip.html#module-references","title":"References - Bumblebee.Multimodal.Clip","type":"module"},{"doc":"LayoutLM Model family.","ref":"Bumblebee.Multimodal.LayoutLm.html","title":"Bumblebee.Multimodal.LayoutLm","type":"module"},{"doc":"* `:base` - plain LayoutLM without any head on top\n\n  * `:for_masked_language_modeling` - LayoutLM with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - LayoutLM with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_token_classification` - LayoutLM with a token classification\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_question_answering` - LayoutLM with a span classification head.\n    The head returns logits for the span start and end positions","ref":"Bumblebee.Multimodal.LayoutLm.html#module-architectures","title":"Architectures - Bumblebee.Multimodal.LayoutLm","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"token_type_ids\"` - `{batch_size, sequence_length}`\n\n    Mask distinguishing groups in the input sequence. This is used\n    in when the input sequence is a semantically a pair of sequences.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"bounding_box\"` - `{batch_size, sequence_length, 4}`\n\n  Bounding boxes of each input sequence token. Each bounding box is\n  `{x0, y0, x1, y1}` where `{x0, y0}` is the upper left corner and\n  `{x1, y1}` is the lower right corner.","ref":"Bumblebee.Multimodal.LayoutLm.html#module-inputs","title":"Inputs - Bumblebee.Multimodal.LayoutLm","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `30522`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `1024`\n\n  * `:max_spatial_positions` - the maximum value of the spatial position embedding. Typically this is set to a large value\n    just in case, such as 512, 1024, or 2048\n    . Defaults to `1024`\n\n  * `:max_token_types` - the vocabulary size of the token type embedding (also referred to as segment embedding).\n    This corresponds to how many different token groups can be distinguished in the input\n    . Defaults to `2`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the decoder. Defaults to `12`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the decoder.\n    If not specified, defaults to 4 times `:hidden_size`\n    . Defaults to `3072`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for embedding and encoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.1`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. If not specified, the value of `:dropout_rate` is used instead\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Multimodal.LayoutLm.html#module-configuration","title":"Configuration - Bumblebee.Multimodal.LayoutLm","type":"module"},{"doc":"* [LayoutLM: LayoutLM: Pre-training of Text and Layout for Document Image Understanding](https://arxiv.org/abs/1912.13318)","ref":"Bumblebee.Multimodal.LayoutLm.html#module-references","title":"References - Bumblebee.Multimodal.LayoutLm","type":"module"},{"doc":"ALBERT model family.","ref":"Bumblebee.Text.Albert.html","title":"Bumblebee.Text.Albert","type":"module"},{"doc":"* `:base` - plain ALBERT without any head on top\n\n  * `:for_masked_language_modeling` - ALBERT with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - ALBERT with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_token_classification` - ALBERT with a token classification\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_question_answering` - ALBERT with a span classification head.\n    The head returns logits for the span start and end positions\n\n  * `:for_multiple_choice` - ALBERT with a multiple choice prediction\n    head. Each input in the batch consists of several sequences to\n    choose from and the model returns logits corresponding to those\n    choices\n\n  * `:for_pre_training` - ALBERT with both MLM and NSP heads as done\n    during the pre-training","ref":"Bumblebee.Text.Albert.html#module-architectures","title":"Architectures - Bumblebee.Text.Albert","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"token_type_ids\"` - `{batch_size, sequence_length}`\n\n    Mask distinguishing groups in the input sequence. This is used\n    in when the input sequence is a semantically a pair of sequences.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n#","ref":"Bumblebee.Text.Albert.html#module-inputs","title":"Inputs - Bumblebee.Text.Albert","type":"module"},{"doc":"The `:for_multiple_choice` model accepts groups of sequences, so the\nexpected sequence shape is `{batch_size, num_choices, sequence_length}`.","ref":"Bumblebee.Text.Albert.html#module-exceptions","title":"Exceptions - Bumblebee.Text.Albert","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `30000`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `512`\n\n  * `:max_token_types` - the vocabulary size of the token type embedding (also referred to as segment embedding).\n    This corresponds to how many different token groups can be distinguished in the input\n    . Defaults to `2`\n\n  * `:embedding_size` - the dimensionality of all input embeddings. Defaults to `128`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of blocks in the encoder. Note that each block contains `:block_depth`\n    Transformer blocks\n    . Defaults to `12`\n\n  * `:num_groups` - the number of groups of encoder blocks. Parameters in the same group are shared. Defaults to `1`\n\n  * `:block_depth` - the number of Transformer blocks in each encoder block. Defaults to `1`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the encoder. Defaults to `16384`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for embedding and encoder. Defaults to `0.0`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. If not specified, the value of `:dropout_rate` is used instead\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Text.Albert.html#module-configuration","title":"Configuration - Bumblebee.Text.Albert","type":"module"},{"doc":"* [ALBERT: A Lite BERT for Self-supervised Learning of Language Representations](https://arxiv.org/abs/1909.11942)","ref":"Bumblebee.Text.Albert.html#module-references","title":"References - Bumblebee.Text.Albert","type":"module"},{"doc":"BART model family.","ref":"Bumblebee.Text.Bart.html","title":"Bumblebee.Text.Bart","type":"module"},{"doc":"* `:base` - plain BART without any head on top\n\n  * `:for_causal_language_modeling` - BART with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_conditional_generation` - BART with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - BART with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_question_answering` - BART with a span classification head.\n    The head returns logits for the span start and end positions","ref":"Bumblebee.Text.Bart.html#module-architectures","title":"Architectures - Bumblebee.Text.Bart","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{encoder_num_blocks, encoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"decoder_input_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of decoder input sequence tokens in the vocabulary. If not\n    present and `\"input_ids\"` is, it will be generated by shifting\n    each token in `\"input_ids\"` to the right once.\n\n  * `\"decoder_attention_mask\"` - `{batch_size, target_sequence_length}`\n\n    Mask indicating which decoder tokens to attend to. This is used\n    to ignore padding tokens, which are added when processing a batch\n    of sequences with different length.\n\n  * `\"decoder_position_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of positions of each decoder input sequence tokens in\n    the position embeddings.\n\n  * `\"decoder_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the decoder.\n\n  * `\"decoder_input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"decoder_input_ids\"`, which can be\n    specified for more control over how `\"decoder_input_ids\"` are\n    embedded than the model's internal embedding lookup. If\n    `\"decoder_input_embeddings\"` are present, then `\"decoder_input_ids\"`\n    will be ignored.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Last hidden state output from the encoder. This hidden state is\n    used in cross-attention blocks in the decoder. If specified, the\n    model will skip the encoding process and use this value directly\n    for cross-attentions in the decoder.\n\n  * `\"cross_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the cross-attention blocks in\n    the decoder with shape.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.\n\n#","ref":"Bumblebee.Text.Bart.html#module-inputs","title":"Inputs - Bumblebee.Text.Bart","type":"module"},{"doc":"The `:for_causal_language_modeling` model is just the decoder part and\naccepts the following inputs instead: `\"input_ids\"`, `\"attention_mask\"`,\n`\"position_ids\"`, `\"attention_head_mask\"`, `\"input_embeddings\"`, `\"encoder_hidden_state\"`,\n`\"encoder_attention_mask\"`, `\"cross_attention_head_mask\"`, `\"cache\"`.","ref":"Bumblebee.Text.Bart.html#module-exceptions","title":"Exceptions - Bumblebee.Text.Bart","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `50265`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `1024`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `1024`\n\n  * `:encoder_num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:decoder_num_blocks` - the number of Transformer blocks in the decoder. Defaults to `12`\n\n  * `:encoder_num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `16`\n\n  * `:decoder_num_attention_heads` - the number of attention heads for each attention layer in the decoder. Defaults to `16`\n\n  * `:scale_embedding` - whether to scale embeddings by dividing by the square root of `:hidden_size`. Defaults to `false`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for encoder and decoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:activation_dropout_rate` - the dropout rate for activations inside fully connected layers. Defaults to `0.0`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. Defaults to `0.0`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Text.Bart.html#module-configuration","title":"Configuration - Bumblebee.Text.Bart","type":"module"},{"doc":"BERT model family.","ref":"Bumblebee.Text.Bert.html","title":"Bumblebee.Text.Bert","type":"module"},{"doc":"* `:base` - plain BERT without any head on top\n\n  * `:for_masked_language_modeling` - BERT with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - BERT with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_token_classification` - BERT with a token classification\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_question_answering` - BERT with a span classification head.\n    The head returns logits for the span start and end positions\n\n  * `:for_multiple_choice` - BERT with a multiple choice prediction\n    head. Each input in the batch consists of several sequences to\n    choose from and the model returns logits corresponding to those\n    choices\n\n  * `:for_next_sentence_prediction` - BERT with a next sentence\n    prediction head. The head returns logits predicting whether the\n    second sentence is random or in context\n\n  * `:for_pre_training` - BERT with both MLM and NSP heads as done\n    during the pre-training\n\n  * `:for_causal_language_modeling` - BERT working as a decoder with\n    a language modeling head. The head returns logits for each token\n    in the original sequence","ref":"Bumblebee.Text.Bert.html#module-architectures","title":"Architectures - Bumblebee.Text.Bert","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"token_type_ids\"` - `{batch_size, sequence_length}`\n\n    Mask distinguishing groups in the input sequence. This is used\n    in when the input sequence is a semantically a pair of sequences.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n#","ref":"Bumblebee.Text.Bert.html#module-inputs","title":"Inputs - Bumblebee.Text.Bert","type":"module"},{"doc":"The `:for_multiple_choice` model accepts groups of sequences, so the\nexpected sequence shape is `{batch_size, num_choices, sequence_length}`.\n\nThe `:for_causal_language_modeling` model is a decoder and accepts\nthe following additional inputs: `\"encoder_hidden_state\"`,\n`\"encoder_attention_mask\"`, `\"cross_attention_head_mask\"`, `\"cache\"`.","ref":"Bumblebee.Text.Bert.html#module-exceptions","title":"Exceptions - Bumblebee.Text.Bert","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `30522`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `512`\n\n  * `:max_token_types` - the vocabulary size of the token type embedding (also referred to as segment embedding).\n    This corresponds to how many different token groups can be distinguished in the input\n    . Defaults to `2`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the encoder. Defaults to `3072`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for embedding and encoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.1`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. If not specified, the value of `:dropout_rate` is used instead\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`\n\n  * `:use_cross_attention` - whether cross-attention layers should be added to the model.This is only relevant for decoder models. Defaults to `false`","ref":"Bumblebee.Text.Bert.html#module-configuration","title":"Configuration - Bumblebee.Text.Bert","type":"module"},{"doc":"* [BERT: Pre-training of Deep Bidirectional Transformers for Language Understanding](https://arxiv.org/abs/1810.04805)","ref":"Bumblebee.Text.Bert.html#module-references","title":"References - Bumblebee.Text.Bert","type":"module"},{"doc":"Blenderbot model family.","ref":"Bumblebee.Text.Blenderbot.html","title":"Bumblebee.Text.Blenderbot","type":"module"},{"doc":"* `:base` - plain Blenderbot without any head on top\n\n  * `:for_conditional_generation` - Blenderbot with a language modeling\n    head. The head returns logits for each token in the original\n    sequence","ref":"Bumblebee.Text.Blenderbot.html#module-architectures","title":"Architectures - Bumblebee.Text.Blenderbot","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{encoder_num_blocks, encoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"decoder_input_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of decoder input sequence tokens in the vocabulary. If not\n    present and `\"input_ids\"` is, it will be generated by shifting\n    each token in `\"input_ids\"` to the right once.\n\n  * `\"decoder_attention_mask\"` - `{batch_size, target_sequence_length}`\n\n    Mask indicating which decoder tokens to attend to. This is used\n    to ignore padding tokens, which are added when processing a batch\n    of sequences with different length.\n\n  * `\"decoder_position_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of positions of each decoder input sequence tokens in\n    the position embeddings.\n\n  * `\"decoder_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the decoder.\n\n  * `\"decoder_input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"decoder_input_ids\"`, which can be\n    specified for more control over how `\"decoder_input_ids\"` are\n    embedded than the model's internal embedding lookup. If\n    `\"decoder_input_embeddings\"` are present, then `\"decoder_input_ids\"`\n    will be ignored.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Last hidden state output from the encoder. This hidden state is\n    used in cross-attention blocks in the decoder. If specified, the\n    model will skip the encoding process and use this value directly\n    for cross-attentions in the decoder.\n\n  * `\"cross_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the cross-attention blocks in\n    the decoder with shape.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Text.Blenderbot.html#module-inputs","title":"Inputs - Bumblebee.Text.Blenderbot","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `8008`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `128`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `2560`\n\n  * `:encoder_num_blocks` - the number of Transformer blocks in the encoder. Defaults to `2`\n\n  * `:decoder_num_blocks` - the number of Transformer blocks in the decoder. Defaults to `24`\n\n  * `:encoder_num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `32`\n\n  * `:decoder_num_attention_heads` - the number of attention heads for each attention layer in the decoder. Defaults to `32`\n\n  * `:scale_embedding` - whether to scale embeddings by dividing by the square root of `:hidden_size`. Defaults to `false`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for encoder and decoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:activation_dropout_rate` - the dropout rate for activations inside fully connected layers. Defaults to `0.0`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`","ref":"Bumblebee.Text.Blenderbot.html#module-configuration","title":"Configuration - Bumblebee.Text.Blenderbot","type":"module"},{"doc":"The BLIP model for text encoding.","ref":"Bumblebee.Text.BlipText.html","title":"Bumblebee.Text.BlipText","type":"module"},{"doc":"* `:base` - the base text model","ref":"Bumblebee.Text.BlipText.html#module-architectures","title":"Architectures - Bumblebee.Text.BlipText","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{encoder_num_blocks, encoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, encoder_sequence_length, encoder_hidden_size}`\n\n    Last hidden state output from the encoder. This hidden state is\n    used in cross-attention blocks in the decoder. If specified, the\n    model will skip the encoding process and use this value directly\n    for cross-attentions in the decoder.\n\n  * `\"encoder_attention_mask\"` - `{batch_size, encoder_sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"cross_attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the cross-attention blocks in\n    the decoder with shape.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Text.BlipText.html#module-inputs","title":"Inputs - Bumblebee.Text.BlipText","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `30524`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `512`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:encoder_hidden_size` - the dimensionality of hidden layers in the vision encoder. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `8`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the encoder. Defaults to `3072`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for embedding and encoder. Defaults to `0.0`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`","ref":"Bumblebee.Text.BlipText.html#module-configuration","title":"Configuration - Bumblebee.Text.BlipText","type":"module"},{"doc":"The CLIP model for text encoding.","ref":"Bumblebee.Text.ClipText.html","title":"Bumblebee.Text.ClipText","type":"module"},{"doc":"* `:base` - the base text model","ref":"Bumblebee.Text.ClipText.html#module-architectures","title":"Architectures - Bumblebee.Text.ClipText","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.","ref":"Bumblebee.Text.ClipText.html#module-inputs","title":"Inputs - Bumblebee.Text.ClipText","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `49408`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `77`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `512`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `8`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the encoder. Defaults to `2048`\n\n  * `:activation` - the activation function. Defaults to `:quick_gelu`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-5`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Text.ClipText.html#module-configuration","title":"Configuration - Bumblebee.Text.ClipText","type":"module"},{"doc":"DistilBERT model family.","ref":"Bumblebee.Text.Distilbert.html","title":"Bumblebee.Text.Distilbert","type":"module"},{"doc":"* `:base` - plain DistilBERT without any head on top\n\n  * `:for_masked_language_modeling` - DistilBERT with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - DistilBERT with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_token_classification` - DistilBERT with a token classification\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_question_answering` - DistilBERT with a span classification head.\n    The head returns logits for the span start and end positions\n\n  * `:for_multiple_choice` - DistilBERT with a multiple choice prediction\n    head. Each input in the batch consists of several sequences to\n    choose from and the model returns logits corresponding to those\n    choices","ref":"Bumblebee.Text.Distilbert.html#module-architectures","title":"Architectures - Bumblebee.Text.Distilbert","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n    Mask distinguishing groups in the input sequence. This is used\n    in when the input sequence is a semantically a pair of sequences.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n#","ref":"Bumblebee.Text.Distilbert.html#module-inputs","title":"Inputs - Bumblebee.Text.Distilbert","type":"module"},{"doc":"The `:for_multiple_choice` model accepts groups of sequences, so the\nexpected sequence shape is `{batch_size, num_choices, sequence_length}`.","ref":"Bumblebee.Text.Distilbert.html#module-exceptions","title":"Exceptions - Bumblebee.Text.Distilbert","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `30522`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `512`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `6`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the encoder. Defaults to `3072`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for embedding and encoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.1`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. If not specified, the value of `:dropout_rate` is used instead\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`\n\n  * `:use_cross_attention` - whether cross-attention layers should be added to the model.This is only relevant for decoder models. Defaults to `false`","ref":"Bumblebee.Text.Distilbert.html#module-configuration","title":"Configuration - Bumblebee.Text.Distilbert","type":"module"},{"doc":"* [DistilBERT, a distilled version of BERT: smaller, faster, cheaper and lighter](https://arxiv.org/abs/1910.01108)","ref":"Bumblebee.Text.Distilbert.html#module-references","title":"References - Bumblebee.Text.Distilbert","type":"module"},{"doc":"GPT-2 model family.","ref":"Bumblebee.Text.Gpt2.html","title":"Bumblebee.Text.Gpt2","type":"module"},{"doc":"* `:base` - plain GPT-2 without any head on top\n\n  * `:for_causal_language_modeling` - GPT-2 with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - GPT-2 with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_token_classification` - GPT-2 with a token classification\n    head. The head returns logits for each token in the original\n    sequence","ref":"Bumblebee.Text.Gpt2.html#module-architectures","title":"Architectures - Bumblebee.Text.Gpt2","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, encoder_sequence_length, hidden_size}`\n\n    Last hidden state output from the encoder. This hidden state is\n    used in cross-attention blocks in the decoder. If specified, the\n    model will skip the encoding process and use this value directly\n    for cross-attentions in the decoder.\n\n  * `\"encoder_attention_mask\"` - `{batch_size, encoder_sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"cross_attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the cross-attention blocks in\n    the decoder with shape.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Text.Gpt2.html#module-inputs","title":"Inputs - Bumblebee.Text.Gpt2","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `50257`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `1024`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the decoder. Defaults to `24`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the decoder. Defaults to `16`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the decoder.\n    If not specified, defaults to 4 times `:hidden_size`\n    \n\n  * `:activation` - the activation function. Defaults to `:gelu_new`\n\n  * `:dropout_rate` - the dropout rate for embedding and encoder. Defaults to `0.1`\n\n  * `:embeddings_dropout_rate` - the dropout rate for embeddings. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.1`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. Defaults to `0.1`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-5`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`\n\n  * `:use_cross_attention` - whether cross-attention layers should be added to the model.This is only relevant for decoder models. Defaults to `false`","ref":"Bumblebee.Text.Gpt2.html#module-configuration","title":"Configuration - Bumblebee.Text.Gpt2","type":"module"},{"doc":"GPT-NeoX model family.","ref":"Bumblebee.Text.GptNeoX.html","title":"Bumblebee.Text.GptNeoX","type":"module"},{"doc":"* `:base` - plain GPT-NeoX without any head on top\n\n  * `:for_causal_language_modeling` - GPT-NeoX with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - GPT-NeoX with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_token_classification` - GPT-NeoX with a token classification\n    head. The head returns logits for each token in the original\n    sequence","ref":"Bumblebee.Text.GptNeoX.html#module-architectures","title":"Architectures - Bumblebee.Text.GptNeoX","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{encoder_num_blocks, encoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Text.GptNeoX.html#module-inputs","title":"Inputs - Bumblebee.Text.GptNeoX","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `32000`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `4096`\n\n  * `:intermediate_size` - the dimensionality of intermediate layers. Defaults to `11008`\n\n  * `:num_blocks` - the number of Transformer blocks in the model. Defaults to `32`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the model. Defaults to `32`\n\n  * `:activation` - the activation function. Defaults to `:silu`\n\n  * `:rotary_embedding_percentage` - percentage of hidden dimensions to allocate to rotary embeddings. Defaults to `0.25`\n\n  * `:rotary_embedding_base` - base for computing rotary embedding frequency. Defaults to `10000`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. Defaults to `0.1`\n\n  * `:layer_norm_epsilon` - the epsilon used by RMS normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:use_parallel_transformer_block` - whether to use the parallel formulation of the Transformer block, where attention and FFN is computed independently. Defaults to `true`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Text.GptNeoX.html#module-configuration","title":"Configuration - Bumblebee.Text.GptNeoX","type":"module"},{"doc":"LLaMA model family.","ref":"Bumblebee.Text.Llama.html","title":"Bumblebee.Text.Llama","type":"module"},{"doc":"* `:base` - plain LLaMA without any head on top\n\n  * `:for_causal_language_modeling` - LLaMA with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - LLaMA with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes","ref":"Bumblebee.Text.Llama.html#module-architectures","title":"Architectures - Bumblebee.Text.Llama","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{encoder_num_blocks, encoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Text.Llama.html#module-inputs","title":"Inputs - Bumblebee.Text.Llama","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `32000`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `1024`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `4096`\n\n  * `:intermediate_size` - the dimensionality of intermediate layers. Defaults to `11008`\n\n  * `:num_blocks` - the number of Transformer blocks in the model. Defaults to `32`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the model. Defaults to `32`\n\n  * `:activation` - the activation function. Defaults to `:silu`\n\n  * `:layer_norm_epsilon` - the epsilon used by RMS normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Text.Llama.html#module-configuration","title":"Configuration - Bumblebee.Text.Llama","type":"module"},{"doc":"mBART model family.","ref":"Bumblebee.Text.Mbart.html","title":"Bumblebee.Text.Mbart","type":"module"},{"doc":"* `:base` - plain mBART without any head on top\n\n  * `:for_causal_language_modeling` - mBART with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_conditional_generation` - mBART with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - mBART with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_question_answering` - mBART with a span classification head.\n    The head returns logits for the span start and end positions","ref":"Bumblebee.Text.Mbart.html#module-architectures","title":"Architectures - Bumblebee.Text.Mbart","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{encoder_num_blocks, encoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"decoder_input_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of decoder input sequence tokens in the vocabulary. If not\n    present and `\"input_ids\"` is, it will be generated by shifting\n    each token in `\"input_ids\"` to the right once.\n\n  * `\"decoder_attention_mask\"` - `{batch_size, target_sequence_length}`\n\n    Mask indicating which decoder tokens to attend to. This is used\n    to ignore padding tokens, which are added when processing a batch\n    of sequences with different length.\n\n  * `\"decoder_position_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of positions of each decoder input sequence tokens in\n    the position embeddings.\n\n  * `\"decoder_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the decoder.\n\n  * `\"decoder_input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"decoder_input_ids\"`, which can be\n    specified for more control over how `\"decoder_input_ids\"` are\n    embedded than the model's internal embedding lookup. If\n    `\"decoder_input_embeddings\"` are present, then `\"decoder_input_ids\"`\n    will be ignored.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Last hidden state output from the encoder. This hidden state is\n    used in cross-attention blocks in the decoder. If specified, the\n    model will skip the encoding process and use this value directly\n    for cross-attentions in the decoder.\n\n  * `\"cross_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the cross-attention blocks in\n    the decoder with shape.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.\n\n#","ref":"Bumblebee.Text.Mbart.html#module-inputs","title":"Inputs - Bumblebee.Text.Mbart","type":"module"},{"doc":"The `:for_causal_language_modeling` model is just the decoder part and\naccepts the following inputs instead: `\"input_ids\"`, `\"attention_mask\"`,\n`\"position_ids\"`, `\"attention_head_mask\"`, `\"input_embeddings\"`, `\"encoder_hidden_state\"`,\n`\"encoder_attention_mask\"`, `\"cross_attention_head_mask\"`, `\"cache\"`.","ref":"Bumblebee.Text.Mbart.html#module-exceptions","title":"Exceptions - Bumblebee.Text.Mbart","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `50265`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `1024`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `1024`\n\n  * `:encoder_num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:decoder_num_blocks` - the number of Transformer blocks in the decoder. Defaults to `12`\n\n  * `:encoder_num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `16`\n\n  * `:decoder_num_attention_heads` - the number of attention heads for each attention layer in the decoder. Defaults to `16`\n\n  * `:encoder_intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the encoder. Defaults to `4096`\n\n  * `:decoder_intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the decoder. Defaults to `4096`\n\n  * `:scale_embedding` - scale embeddings by dividing by sqrt(hidden_size). Defaults to `false`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for encoder and decoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:activation_dropout_rate` - the dropout rate for activations inside fully connected layers. Defaults to `0.0`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. Defaults to `0.0`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Text.Mbart.html#module-configuration","title":"Configuration - Bumblebee.Text.Mbart","type":"module"},{"doc":"RoBERTa model family.","ref":"Bumblebee.Text.Roberta.html","title":"Bumblebee.Text.Roberta","type":"module"},{"doc":"* `:base` - plain RoBERTa without any head on top\n\n  * `:for_masked_language_modeling` - RoBERTa with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_sequence_classification` - RoBERTa with a sequence\n    classification head. The head returns logits corresponding to\n    possible classes\n\n  * `:for_token_classification` - RoBERTa with a token classification\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:for_question_answering` - RoBERTa with a span classification head.\n    The head returns logits for the span start and end positions\n\n  * `:for_multiple_choice` - RoBERTa with a multiple choice prediction\n    head. Each input in the batch consists of several sequences to\n    choose from and the model returns logits corresponding to those\n    choices\n\n  * `:for_causal_language_modeling` - RoBERTa working as a decoder with\n    a language modeling head. The head returns logits for each token in\n    the original sequence","ref":"Bumblebee.Text.Roberta.html#module-architectures","title":"Architectures - Bumblebee.Text.Roberta","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"token_type_ids\"` - `{batch_size, sequence_length}`\n\n    Mask distinguishing groups in the input sequence. This is used\n    in when the input sequence is a semantically a pair of sequences.\n\n  * `\"position_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of positions of each input sequence tokens in the position\n    embeddings.\n\n  * `\"attention_head_mask\"` - `{num_blocks, num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n#","ref":"Bumblebee.Text.Roberta.html#module-inputs","title":"Inputs - Bumblebee.Text.Roberta","type":"module"},{"doc":"The `:for_multiple_choice` model accepts groups of sequences, so the\nexpected sequence shape is `{batch_size, num_choices, sequence_length}`.\n\nThe `:for_causal_language_modeling` model is a decoder and accepts\nthe following additional inputs: `\"encoder_hidden_state\"`,\n`\"encoder_attention_mask\"`, `\"cross_attention_head_mask\"`, `\"cache\"`.","ref":"Bumblebee.Text.Roberta.html#module-exceptions","title":"Exceptions - Bumblebee.Text.Roberta","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `30522`\n\n  * `:max_positions` - the vocabulary size of the position embedding. This corresponds to the maximum sequence\n    length that this model can process. Typically this is set to a large value just in case,\n    such as 512, 1024 or 2048\n    . Defaults to `512`\n\n  * `:max_token_types` - the vocabulary size of the token type embedding (also referred to as segment embedding).\n    This corresponds to how many different token groups can be distinguished in the input\n    . Defaults to `2`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:intermediate_size` - the dimensionality of the intermediate layer in the transformer feed-forward network (FFN) in the encoder. Defaults to `3072`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for embedding and encoder. Defaults to `0.1`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.1`\n\n  * `:classifier_dropout_rate` - the dropout rate for the classification head. If not specified, the value of `:dropout_rate` is used instead\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_range` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`\n\n  * `:use_cross_attention` - whether cross-attention layers should be added to the model.This is only relevant for decoder models. Defaults to `false`","ref":"Bumblebee.Text.Roberta.html#module-configuration","title":"Configuration - Bumblebee.Text.Roberta","type":"module"},{"doc":"T5 model family.","ref":"Bumblebee.Text.T5.html","title":"Bumblebee.Text.T5","type":"module"},{"doc":"* `:base` - plain T5 without any head on top\n\n  * `:for_conditional_generation` - T5 with a language modeling\n    head. The head returns logits for each token in the original\n    sequence\n\n  * `:encoder` - just the encoder part of the base model","ref":"Bumblebee.Text.T5.html#module-architectures","title":"Architectures - Bumblebee.Text.T5","type":"module"},{"doc":"* `\"input_ids\"` - `{batch_size, sequence_length}`\n\n    Indices of input sequence tokens in the vocabulary.\n\n  * `\"attention_mask\"` - `{batch_size, sequence_length}`\n\n    Mask indicating which tokens to attend to. This is used to ignore\n    padding tokens, which are added when processing a batch of sequences\n    with different length.\n\n  * `\"attention_head_mask\"` - `{encoder_num_blocks, encoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the encoder.\n\n  * `\"input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"input_ids\"`, which can be specified\n    for more control over how `\"input_ids\"` are embedded than the\n    model's internal embedding lookup. If `\"input_embeddings\"` are present,\n    then `\"input_ids\"` will be ignored.\n\n  * `\"decoder_input_ids\"` - `{batch_size, target_sequence_length}`\n\n    Indices of decoder input sequence tokens in the vocabulary. If not\n    present and `\"input_ids\"` is, it will be generated by shifting\n    each token in `\"input_ids\"` to the right once.\n\n  * `\"decoder_attention_mask\"` - `{batch_size, target_sequence_length}`\n\n    Mask indicating which decoder tokens to attend to. This is used\n    to ignore padding tokens, which are added when processing a batch\n    of sequences with different length.\n\n  * `\"decoder_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the self-attention blocks in\n    the decoder.\n\n  * `\"decoder_input_embeddings\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Embedded representation of `\"decoder_input_ids\"`, which can be\n    specified for more control over how `\"decoder_input_ids\"` are\n    embedded than the model's internal embedding lookup. If\n    `\"decoder_input_embeddings\"` are present, then `\"decoder_input_ids\"`\n    will be ignored.\n\n  * `\"encoder_hidden_state\"` - `{batch_size, sequence_length, hidden_size}`\n\n    Last hidden state output from the encoder. This hidden state is\n    used in cross-attention blocks in the decoder. If specified, the\n    model will skip the encoding process and use this value directly\n    for cross-attentions in the decoder.\n\n  * `\"cross_attention_head_mask\"` - `{decoder_num_blocks, decoder_num_attention_heads}`\n\n    Mask to nullify selected heads of the cross-attention blocks in\n    the decoder with shape.\n\n  * `\"cache\"`\n\n    A container with cached layer results used to speed up sequential\n    decoding (autoregression). With cache, certain hidden states are\n    taken from the cache, rather than recomputed on every decoding\n    pass. The cache should be treated as opaque and initialized with\n    `Bumblebee.Text.Generation.init_cache/4`.","ref":"Bumblebee.Text.T5.html#module-inputs","title":"Inputs - Bumblebee.Text.T5","type":"module"},{"doc":"* `:vocab_size` - the vocabulary size of the token embedding. This corresponds to the number of distinct\n    tokens that can be represented in model input and output\n    . Defaults to `32128`\n\n  * `:tie_word_embeddings` - whether or not to tie encoder and decoder token embedding\n    . Defaults to `true`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `512`\n\n  * `:attention_head_size` - the size of the key, value, and query projection per attention head. Defaults to `64`\n\n  * `:encoder_num_blocks` - the number of Transformer blocks in the encoder. Defaults to `6`\n\n  * `:decoder_num_blocks` - the number of Transformer blocks in the decoder. Defaults to `6`\n\n  * `:encoder_num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `8`\n\n  * `:decoder_num_attention_heads` - the number of attention heads for each attention layer in the decoder. Defaults to `8`\n\n  * `:activation` - the activation function. Defaults to `:relu`\n\n  * `:ffn_gated_activation` - whether to use a gated variant of the activation function in the feed-forward network (FFN). Defaults to `false`\n\n  * `:dropout_rate` - the dropout rate for encoder and decoder. Defaults to `0.1`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `1.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-6`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Text.T5.html#module-configuration","title":"Configuration - Bumblebee.Text.T5","type":"module"},{"doc":"The BLIP model for image encoding.","ref":"Bumblebee.Vision.BlipVision.html","title":"Bumblebee.Vision.BlipVision","type":"module"},{"doc":"* `:base` - the base image model","ref":"Bumblebee.Vision.BlipVision.html#module-architectures","title":"Architectures - Bumblebee.Vision.BlipVision","type":"module"},{"doc":"* `\"pixel_values\"` - `{batch_size, image_size, image_size, num_channels}`\n\n    Featurized image pixel values.","ref":"Bumblebee.Vision.BlipVision.html#module-inputs","title":"Inputs - Bumblebee.Vision.BlipVision","type":"module"},{"doc":"* `:image_size` - the size of the input spatial dimensions. Defaults to `384`\n\n  * `:num_channels` - the number of channels in the input. Defaults to `3`\n\n  * `:patch_size` - the size of the patch spatial dimensions. Defaults to `16`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-5`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`","ref":"Bumblebee.Vision.BlipVision.html#module-configuration","title":"Configuration - Bumblebee.Vision.BlipVision","type":"module"},{"doc":"The CLIP model for image encoding.","ref":"Bumblebee.Vision.ClipVision.html","title":"Bumblebee.Vision.ClipVision","type":"module"},{"doc":"* `:base` - the base image model","ref":"Bumblebee.Vision.ClipVision.html#module-architectures","title":"Architectures - Bumblebee.Vision.ClipVision","type":"module"},{"doc":"* `\"pixel_values\"` - `{batch_size, image_size, image_size, num_channels}`\n\n    Featurized image pixel values.","ref":"Bumblebee.Vision.ClipVision.html#module-inputs","title":"Inputs - Bumblebee.Vision.ClipVision","type":"module"},{"doc":"* `:image_size` - the size of the input spatial dimensions. Defaults to `224`\n\n  * `:num_channels` - the number of channels in the input. Defaults to `3`\n\n  * `:patch_size` - the size of the patch spatial dimensions. Defaults to `32`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:activation` - the activation function. Defaults to `:quick_gelu`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-5`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`","ref":"Bumblebee.Vision.ClipVision.html#module-configuration","title":"Configuration - Bumblebee.Vision.ClipVision","type":"module"},{"doc":"ConvNeXT model family.","ref":"Bumblebee.Vision.ConvNext.html","title":"Bumblebee.Vision.ConvNext","type":"module"},{"doc":"* `:base` - plain ConvNeXT without any head on top\n\n  * `:for_image_classification` - ConvNeXT with a classification head.\n    The head consists of a single dense layer on top of the pooled\n    features","ref":"Bumblebee.Vision.ConvNext.html#module-architectures","title":"Architectures - Bumblebee.Vision.ConvNext","type":"module"},{"doc":"* `\"pixel_values\"` - {batch_size, height, width, num_channels}\n\n    Featurized image pixel values (224x224).","ref":"Bumblebee.Vision.ConvNext.html#module-inputs","title":"Inputs - Bumblebee.Vision.ConvNext","type":"module"},{"doc":"* `:num_channels` - the number of channels in the input. Defaults to `3`\n\n  * `:patch_size` - the size of the patch spatial dimensions. Defaults to `4`\n\n  * `:hidden_sizes` - the dimensionality of hidden layers at each stage. Defaults to `[96, 192, 384, 768]`\n\n  * `:depths` - the depth (number of residual blocks) at each stage. Defaults to `[3, 3, 9, 3]`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:scale_initial_value` - the initial value for scaling layers. Defaults to `1.0e-6`\n\n  * `:drop_path_rate` - the drop path rate used to for stochastic depth. Defaults to `0.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Vision.ConvNext.html#module-configuration","title":"Configuration - Bumblebee.Vision.ConvNext","type":"module"},{"doc":"* [A ConvNet for the 2020s](https://arxiv.org/abs/2201.03545)","ref":"Bumblebee.Vision.ConvNext.html#module-references","title":"References - Bumblebee.Vision.ConvNext","type":"module"},{"doc":"DeiT model family.","ref":"Bumblebee.Vision.Deit.html","title":"Bumblebee.Vision.Deit","type":"module"},{"doc":"* `:base` - plain DeiT without any head on top\n\n  * `:for_image_classification` - DeiT with a classification head.\n    The head consists of two dense layers on top of the final\n    hidden state of the CLS token\n\n  * `:for_image_classification_with teacher` - DeiT with a\n    classification head. The head consists of two dense layers\n    on top of the final hidden state of the CLS token and the\n    final hidden state of the distillation token\n\n  * `:for_masked_image_modeling` - DEiT with a language modeling\n    head on top for predicting visual tokens","ref":"Bumblebee.Vision.Deit.html#module-architectures","title":"Architectures - Bumblebee.Vision.Deit","type":"module"},{"doc":"* `\"pixel_values\"` - `{batch_size, image_size, image_size, num_channels}`\n\n    Featurized image pixel values.\n\n  * `\"patch_mask\"` - `{batch_size, num_patches}`\n\n    Mask to nullify selected embedded patches.","ref":"Bumblebee.Vision.Deit.html#module-inputs","title":"Inputs - Bumblebee.Vision.Deit","type":"module"},{"doc":"* `:image_size` - the size of the input spatial dimensions. Defaults to `224`\n\n  * `:num_channels` - the number of channels in the input. Defaults to `3`\n\n  * `:patch_size` - the size of the patch spatial dimensions. Defaults to `16`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:use_qkv_bias` - whether to use bias in query, key, and value projections. Defaults to `true`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for encoder and decoder. Defaults to `0.0`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Vision.Deit.html#module-configuration","title":"Configuration - Bumblebee.Vision.Deit","type":"module"},{"doc":"* [An Image is Worth 16x16 Words: Transformers for Image Recognition at Scale](https://arxiv.org/abs/2010.11929)","ref":"Bumblebee.Vision.Deit.html#module-references","title":"References - Bumblebee.Vision.Deit","type":"module"},{"doc":"ResNet model family.","ref":"Bumblebee.Vision.ResNet.html","title":"Bumblebee.Vision.ResNet","type":"module"},{"doc":"* `:base` - plain ResNet without any head on top\n\n  * `:for_image_classification` - ResNet with a classification head.\n    The head consists of a single dense layer on top of the pooled\n    features and it returns logits corresponding to possible classes","ref":"Bumblebee.Vision.ResNet.html#module-architectures","title":"Architectures - Bumblebee.Vision.ResNet","type":"module"},{"doc":"* `\"pixel_values\"` - {batch_size, height, width, num_channels}\n\n    Featurized image pixel values (224x224).","ref":"Bumblebee.Vision.ResNet.html#module-inputs","title":"Inputs - Bumblebee.Vision.ResNet","type":"module"},{"doc":"* `:num_channels` - the number of channels in the input. Defaults to `3`\n\n  * `:embedding_size` - the dimensionality of the embedding layer. Defaults to `64`\n\n  * `:hidden_sizes` - the dimensionality of hidden layers at each stage. Defaults to `[256, 512, 1024, 2048]`\n\n  * `:depths` - the depth (number of residual blocks) at each stage. Defaults to `[3, 4, 6, 3]`\n\n  * `:residual_block_type` - the residual block to use, either `:basic` (used for smaller models, like ResNet-18 or ResNet-34)\n    or `:bottleneck` (used for larger models like ResNet-50 and above)\n    . Defaults to `:bottleneck`\n\n  * `:activation` - the activation function. Defaults to `:relu`\n\n  * `:downsample_in_first_stage` - whether the first stage should downsample the inputs using a stride of 2. Defaults to `false`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Vision.ResNet.html#module-configuration","title":"Configuration - Bumblebee.Vision.ResNet","type":"module"},{"doc":"ViT model family.","ref":"Bumblebee.Vision.Vit.html","title":"Bumblebee.Vision.Vit","type":"module"},{"doc":"* `:base` - plain ViT without any head on top\n\n  * `:for_image_classification` - ViT with a classification head.\n    The head consists of a single dense layer on top of the pooled\n    features\n\n  * `:for_masked_image_modeling` - ViT with a language modeling\n    head on top for predicting visual tokens","ref":"Bumblebee.Vision.Vit.html#module-architectures","title":"Architectures - Bumblebee.Vision.Vit","type":"module"},{"doc":"* `\"pixel_values\"` - `{batch_size, image_size, image_size, num_channels}`\n\n    Featurized image pixel values.\n\n  * `\"patch_mask\"` - `{batch_size, num_patches}`\n\n    Mask to nullify selected embedded patches.","ref":"Bumblebee.Vision.Vit.html#module-inputs","title":"Inputs - Bumblebee.Vision.Vit","type":"module"},{"doc":"* `:image_size` - the size of the input spatial dimensions. Defaults to `224`\n\n  * `:num_channels` - the number of channels in the input. Defaults to `3`\n\n  * `:patch_size` - the size of the patch spatial dimensions. Defaults to `16`\n\n  * `:hidden_size` - the dimensionality of hidden layers. Defaults to `768`\n\n  * `:num_blocks` - the number of Transformer blocks in the encoder. Defaults to `12`\n\n  * `:num_attention_heads` - the number of attention heads for each attention layer in the encoder. Defaults to `12`\n\n  * `:use_qkv_bias` - whether to use bias in query, key, and value projections. Defaults to `true`\n\n  * `:activation` - the activation function. Defaults to `:gelu`\n\n  * `:dropout_rate` - the dropout rate for encoder and decoder. Defaults to `0.0`\n\n  * `:attention_dropout_rate` - the dropout rate for attention weights. Defaults to `0.0`\n\n  * `:layer_norm_epsilon` - the epsilon used by the layer normalization layers. Defaults to `1.0e-12`\n\n  * `:initializer_scale` - the standard deviation of the normal initializer used for initializing kernel parameters. Defaults to `0.02`\n\n  * `:output_hidden_states` - whether the model should return all hidden states. Defaults to `false`\n\n  * `:output_attentions` - whether the model should return all attentions. Defaults to `false`\n\n  * `:num_labels` - the number of labels to use in the last layer for the classification task. Defaults to `2`\n\n  * `:id_to_label` - a map from class index to label. Defaults to `%{}`","ref":"Bumblebee.Vision.Vit.html#module-configuration","title":"Configuration - Bumblebee.Vision.Vit","type":"module"},{"doc":"* [An Image is Worth 16x16 Words: Transformers for Image Recognition at Scale](https://arxiv.org/abs/2010.11929)","ref":"Bumblebee.Vision.Vit.html#module-references","title":"References - Bumblebee.Vision.Vit","type":"module"},{"doc":"Whisper featurizer for audio data.","ref":"Bumblebee.Audio.WhisperFeaturizer.html","title":"Bumblebee.Audio.WhisperFeaturizer","type":"module"},{"doc":"* `:feature_size` - the dimension of the extracted features. This corresponds to the number of Mel bins. Defaults to `80`\n\n  * `:sampling_rate` - the sampling rate at which the audio files should be digitally expressed in Hertz. Defaults to `16000`\n\n  * `:num_seconds` - the maximum duration of the audio sequence. This implies that the the maximum length of the\n    input sequence is `:num_seconds` * `:sampling_rate`\n    . Defaults to `30`\n\n  * `:hop_length` - the hop between consecutive overlapping windows for the STFT used to obtain Mel Frequency coefficients. Defaults to `160`\n\n  * `:fft_length` - the size of the fourier transform. Defaults to `400`\n\n  * `:padding_value` - the value used to pad the audio. Should correspond to silence. Defaults to `0.0`","ref":"Bumblebee.Audio.WhisperFeaturizer.html#module-configuration","title":"Configuration - Bumblebee.Audio.WhisperFeaturizer","type":"module"},{"doc":"ALBERT tokenizer.","ref":"Bumblebee.Text.AlbertTokenizer.html","title":"Bumblebee.Text.AlbertTokenizer","type":"module"},{"doc":"BART tokenizer.","ref":"Bumblebee.Text.BartTokenizer.html","title":"Bumblebee.Text.BartTokenizer","type":"module"},{"doc":"BERT tokenizer.","ref":"Bumblebee.Text.BertTokenizer.html","title":"Bumblebee.Text.BertTokenizer","type":"module"},{"doc":"Blenderbot tokenizer.","ref":"Bumblebee.Text.BlenderbotTokenizer.html","title":"Bumblebee.Text.BlenderbotTokenizer","type":"module"},{"doc":"Camembert tokenizer.","ref":"Bumblebee.Text.CamembertTokenizer.html","title":"Bumblebee.Text.CamembertTokenizer","type":"module"},{"doc":"CLIP tokenizer.","ref":"Bumblebee.Text.ClipTokenizer.html","title":"Bumblebee.Text.ClipTokenizer","type":"module"},{"doc":"DistilBERT tokenizer.","ref":"Bumblebee.Text.DistilbertTokenizer.html","title":"Bumblebee.Text.DistilbertTokenizer","type":"module"},{"doc":"GPT-2 tokenizer.","ref":"Bumblebee.Text.Gpt2Tokenizer.html","title":"Bumblebee.Text.Gpt2Tokenizer","type":"module"},{"doc":"GPT-NeoX tokenizer.","ref":"Bumblebee.Text.GptNeoXTokenizer.html","title":"Bumblebee.Text.GptNeoXTokenizer","type":"module"},{"doc":"LayoutLM tokenizer.","ref":"Bumblebee.Text.LayoutLmTokenizer.html","title":"Bumblebee.Text.LayoutLmTokenizer","type":"module"},{"doc":"Llama tokenizer.","ref":"Bumblebee.Text.LlamaTokenizer.html","title":"Bumblebee.Text.LlamaTokenizer","type":"module"},{"doc":"mBART tokenizer.","ref":"Bumblebee.Text.MbartTokenizer.html","title":"Bumblebee.Text.MbartTokenizer","type":"module"},{"doc":"RoBERTa tokenizer.","ref":"Bumblebee.Text.RobertaTokenizer.html","title":"Bumblebee.Text.RobertaTokenizer","type":"module"},{"doc":"T5 tokenizer.","ref":"Bumblebee.Text.T5Tokenizer.html","title":"Bumblebee.Text.T5Tokenizer","type":"module"},{"doc":"Whisper tokenizer.","ref":"Bumblebee.Text.WhisperTokenizer.html","title":"Bumblebee.Text.WhisperTokenizer","type":"module"},{"doc":"XLM-RoBERTa tokenizer.","ref":"Bumblebee.Text.XlmRobertaTokenizer.html","title":"Bumblebee.Text.XlmRobertaTokenizer","type":"module"},{"doc":"BLIP featurizer for image data.","ref":"Bumblebee.Vision.BlipFeaturizer.html","title":"Bumblebee.Vision.BlipFeaturizer","type":"module"},{"doc":"* `:resize` - whether to resize (and optionally center crop) the input to the given `:size`. Defaults to `true`\n\n  * `:size` - the size to resize the input to. Either a single number or a `{height, width}` tuple.\n    Only has an effect if `:resize` is `true`\n    . Defaults to `384`\n\n  * `:resize_method` - the resizing method, either of `:nearest`, `:bilinear`, `:bicubic`, `:lanczos3`, `:lanczos5`. Defaults to `:bicubic`\n\n  * `:normalize` - whether or not to normalize the input with mean and standard deviation. Defaults to `true`\n\n  * `:image_mean` - the sequence of mean values for each channel, to be used when normalizing images. Defaults to `[0.48145466, 0.4578275, 0.40821073]`\n\n  * `:image_std` - the sequence of standard deviations for each channel, to be used when normalizing images. Defaults to `[0.26862954, 0.26130258, 0.27577711]`","ref":"Bumblebee.Vision.BlipFeaturizer.html#module-configuration","title":"Configuration - Bumblebee.Vision.BlipFeaturizer","type":"module"},{"doc":"CLIP featurizer for image data.","ref":"Bumblebee.Vision.ClipFeaturizer.html","title":"Bumblebee.Vision.ClipFeaturizer","type":"module"},{"doc":"* `:resize` - whether to resize (and optionally center crop) the input to the given `:size`. Defaults to `true`\n\n  * `:size` - the size to resize the input to. The image is resized to (`:size`, `:size`). Only has\n    an effect if `:resize` is `true`\n    . Defaults to `224`\n\n  * `:resize_method` - the resizing method, either of `:nearest`, `:bilinear`, `:bicubic`, `:lanczos3`, `:lanczos5`. Defaults to `:bicubic`\n\n  * `:center_crop` - whether to crop the input at the center. If the input size is smaller than `:crop_size` along\n    any edge, the image is padded with zeros and then center cropped\n    . Defaults to `true`\n\n  * `:crop_size` - the size to center crop the image to. Only has an effect if `:center_crop` is `true`. Defaults to `224`\n\n  * `:normalize` - whether or not to normalize the input with mean and standard deviation. Defaults to `true`\n\n  * `:image_mean` - the sequence of mean values for each channel, to be used when normalizing images. Defaults to `[0.485, 0.456, 0.406]`\n\n  * `:image_std` - the sequence of standard deviations for each channel, to be used when normalizing images. Defaults to `[0.229, 0.224, 0.225]`","ref":"Bumblebee.Vision.ClipFeaturizer.html#module-configuration","title":"Configuration - Bumblebee.Vision.ClipFeaturizer","type":"module"},{"doc":"ConvNeXT featurizer for image data.","ref":"Bumblebee.Vision.ConvNextFeaturizer.html","title":"Bumblebee.Vision.ConvNextFeaturizer","type":"module"},{"doc":"* `:resize` - whether to resize (and optionally center crop) the input to the given `:size`. Defaults to `true`\n\n  * `:size` - the size to resize the input to. If 384 or larger, the image is resized to (`:size`, `:size`).\n    Otherwise, the shorter edge of the image is matched to `:size` / `:crop_percentage`, then image\n    is cropped to `:size`. Only has an effect if `:resize` is `true`\n    . Defaults to `224`\n\n  * `:resize_method` - the resizing method, either of `:nearest`, `:bilinear`, `:bicubic`, `:lanczos3`, `:lanczos5`. Defaults to `:bicubic`\n\n  * `:crop_percentage` - the percentage of the image to crop. Only has an effect if `:resize` is `true` and `:size` < 384. Defaults to `0.875`\n\n  * `:normalize` - whether or not to normalize the input with mean and standard deviation. Defaults to `true`\n\n  * `:image_mean` - the sequence of mean values for each channel, to be used when normalizing images. Defaults to `[0.485, 0.456, 0.406]`\n\n  * `:image_std` - the sequence of standard deviations for each channel, to be used when normalizing images. Defaults to `[0.229, 0.224, 0.225]`","ref":"Bumblebee.Vision.ConvNextFeaturizer.html#module-configuration","title":"Configuration - Bumblebee.Vision.ConvNextFeaturizer","type":"module"},{"doc":"DeiT featurizer for image data.","ref":"Bumblebee.Vision.DeitFeaturizer.html","title":"Bumblebee.Vision.DeitFeaturizer","type":"module"},{"doc":"* `:resize` - whether to resize (and optionally center crop) the input to the given `:size`. Defaults to `true`\n\n  * `:size` - the size to resize the input to. Either a single number or a `{height, width}` tuple.\n    Only has an effect if `:resize` is `true`\n    . Defaults to `256`\n\n  * `:resize_method` - the resizing method, either of `:nearest`, `:bilinear`, `:bicubic`, `:lanczos3`, `:lanczos5`. Defaults to `:bicubic`\n\n  * `:center_crop` - whether to crop the input at the center. If the input size is smaller than `:crop_size` along\n    any edge, the image is padded with zeros and then center cropped\n    . Defaults to `true`\n\n  * `:crop_size` - the size to center crop the image to. Only has an effect if `:center_crop` is `true`. Defaults to `224`\n\n  * `:normalize` - whether or not to normalize the input with mean and standard deviation. Defaults to `true`\n\n  * `:image_mean` - the sequence of mean values for each channel, to be used when normalizing images. Defaults to `[0.485, 0.456, 0.406]`\n\n  * `:image_std` - the sequence of standard deviations for each channel, to be used when normalizing images. Defaults to `[0.229, 0.224, 0.225]`","ref":"Bumblebee.Vision.DeitFeaturizer.html#module-configuration","title":"Configuration - Bumblebee.Vision.DeitFeaturizer","type":"module"},{"doc":"ViT featurizer for image data.","ref":"Bumblebee.Vision.VitFeaturizer.html","title":"Bumblebee.Vision.VitFeaturizer","type":"module"},{"doc":"* `:resize` - whether to resize the input to the given `:size`. Defaults to `true`\n\n  * `:size` - the size to resize the input to. Either a single number or a `{height, width}` tuple.\n    Only has an effect if `:resize` is `true`\n    . Defaults to `224`\n\n  * `:resize_method` - the resizing method, either of `:nearest`, `:bilinear`, `:bicubic`, `:lanczos3`, `:lanczos5`. Defaults to `:bilinear`\n\n  * `:normalize` - whether or not to normalize the input with mean and standard deviation. Defaults to `true`\n\n  * `:image_mean` - the sequence of mean values for each channel, to be used when normalizing images. Defaults to `[0.5, 0.5, 0.5]`\n\n  * `:image_std` - the sequence of standard deviations for each channel, to be used when normalizing images. Defaults to `[0.5, 0.5, 0.5]`","ref":"Bumblebee.Vision.VitFeaturizer.html#module-configuration","title":"Configuration - Bumblebee.Vision.VitFeaturizer","type":"module"},{"doc":"Denoising diffusion implicit models (DDIMs).\n\nThis sampling method was proposed as a follow up to the original\ndenoising diffusion probabilistic models (DDPMs) in order to heavily\nreduce the number of steps during inference. DDPMs model the diffusion\nprocess as a Markov chain; DDIMs generalize this considering\nnon-Markovian diffusion processes that lead to the same objective.\nThis enables a reverse process with many less samples, as compared\nto DDPMs, while using the same denoising model.\n\nDDIMs were shown to be a simple variant of pseudo numerical methods\nfor diffusion models (PNDMs), see `Bumblebee.Diffusion.PndmScheduler`\nand the corresponding paper for more details.","ref":"Bumblebee.Diffusion.DdimScheduler.html","title":"Bumblebee.Diffusion.DdimScheduler","type":"module"},{"doc":"* `:num_train_steps` - the number of diffusion steps used to train the model. Defaults to `1000`\n\n  * `:beta_schedule` - the beta schedule type, a mapping from a beta range to a sequence of betas for stepping the model.\n    Either of `:linear`, `:quadratic`, or `:squared_cosine`\n    . Defaults to `:linear`\n\n  * `:beta_start` - the start value for the beta schedule. Defaults to `0.0001`\n\n  * `:beta_end` - the end value for the beta schedule. Defaults to `0.02`\n\n  * `:prediction_type` - prediction type of the denoising model. Either of:\n    \n      * `:noise` (default) - the model predicts the noise of the diffusion process\n    \n      * `:angular_velocity` - the model predicts velocity in angular parameterization.\n        See Section 2.4 in [Imagen Video: High Definition Video Generation with Diffusion Models](https://imagen.research.google/video/paper.pdf),\n        then Section 4 in [Progressive Distillation for Fast Sampling of Diffusion Models](https://arxiv.org/pdf/2202.00512.pdf)\n        and Appendix D\n    \n    . Defaults to `:noise`\n\n  * `:alpha_clip_strategy` - each step $t$ uses the values of $\\bar{\\alpha}\\_t$ and $\\bar{\\alpha}\\_{t-1}$,\n    however for $t = 0$ there is no previous alpha. The strategy can be either\n    `:one` ($\\bar{\\alpha}\\_{t-1} = 1$) or `:alpha_zero` ($\\bar{\\alpha}\\_{t-1} = \\bar{\\alpha}\\_0$)\n    . Defaults to `:one`\n\n  * `:timesteps_offset` - an offset added to the inference steps. You can use a combination of `timesteps_offset: 1` and\n    `alpha_clip_strategy: :alpha_zero`, so that the last step $t = 1$ uses $\\bar{\\alpha}\\_1$\n    and $\\bar{\\alpha}\\_0$, as done in stable diffusion\n    . Defaults to `0`\n\n  * `:clip_denoised_sample` - whether to clip the predicted denoised sample ($x_0$ in Equation (12)) into $[-1, 1]$\n    for numerical stability.\n    . Defaults to `true`\n\n  * `:rederive_noise` - whether the noise (output of the denoising model) should be re-derived at each step based on the\n    predicted denoised sample ($x_0$) and the current sample. This technique is used in OpenAI GLIDE\n    . Defaults to `false`\n\n  * `:eta` - a weight for the noise added in a denoising diffusion step. This scales the value of $\\sigma_t$\n    in Equation (12) in the original paper, as per Equation (16)\n    . Defaults to `0.0`","ref":"Bumblebee.Diffusion.DdimScheduler.html#module-configuration","title":"Configuration - Bumblebee.Diffusion.DdimScheduler","type":"module"},{"doc":"* [Denoising Diffusion Implicit Models](https://arxiv.org/abs/2010.02502)","ref":"Bumblebee.Diffusion.DdimScheduler.html#module-references","title":"References - Bumblebee.Diffusion.DdimScheduler","type":"module"},{"doc":"Pseudo numerical methods for diffusion models (PNDMs).\n\nThe sampling is based on two numerical methods for solving ODE: the\nRunge-Kutta method (RK) and the linear multi-step method (LMS). The\ngradient at each step is computed according to either of these methods,\nhowever the transfer part (approximating the next sample based on\ncurrent sample and gradient) is non-linear. Because of this property,\nthe authors of the paper refer to them as pseudo numerical methods,\ndenoted as PRK and PLMS respectively.","ref":"Bumblebee.Diffusion.PndmScheduler.html","title":"Bumblebee.Diffusion.PndmScheduler","type":"module"},{"doc":"* `:num_train_steps` - the number of diffusion steps used to train the model. Defaults to `1000`\n\n  * `:beta_schedule` - the beta schedule type, a mapping from a beta range to a sequence of betas for stepping the model.\n    Either of `:linear`, `:quadratic`, or `:squared_cosine`\n    . Defaults to `:linear`\n\n  * `:beta_start` - the start value for the beta schedule. Defaults to `0.0001`\n\n  * `:beta_end` - the end value for the beta schedule. Defaults to `0.02`\n\n  * `:alpha_clip_strategy` - each step $t$ uses the values of $\\bar{\\alpha}\\_t$ and $\\bar{\\alpha}\\_{t-1}$,\n    however for $t = 0$ there is no previous alpha. The strategy can be either\n    `:one` ($\\bar{\\alpha}\\_{t-1} = 1$) or `:alpha_zero` ($\\bar{\\alpha}\\_{t-1} = \\bar{\\alpha}\\_0$)\n    . Defaults to `:one`\n\n  * `:timesteps_offset` - an offset added to the inference steps. You can use a combination of `timesteps_offset: 1` and\n    `alpha_clip_strategy: :alpha_zero`, so that the last step $t = 1$ uses $\\bar{\\alpha}\\_1$\n    and $\\bar{\\alpha}\\_0$, as done in stable diffusion\n    . Defaults to `0`\n\n  * `:reduce_warmup` - when `true`, the first few samples are computed using lower-order linear multi-step,\n    rather than the Runge-Kutta method. This results in less forward passes of the model\n    . Defaults to `false`","ref":"Bumblebee.Diffusion.PndmScheduler.html#module-configuration","title":"Configuration - Bumblebee.Diffusion.PndmScheduler","type":"module"},{"doc":"* [Pseudo Numerical Methods for Diffusion Models on Manifolds](https://arxiv.org/abs/2202.09778)","ref":"Bumblebee.Diffusion.PndmScheduler.html#module-references","title":"References - Bumblebee.Diffusion.PndmScheduler","type":"module"},{"doc":"An interface for configurable entities.\n\nA module implementing this behaviour is expected to define a struct\nwith configuration.","ref":"Bumblebee.Configurable.html","title":"Bumblebee.Configurable","type":"behaviour"},{"doc":"Configures the struct.","ref":"Bumblebee.Configurable.html#c:config/2","title":"Bumblebee.Configurable.config/2","type":"callback"},{"doc":"","ref":"Bumblebee.Configurable.html#t:t/0","title":"Bumblebee.Configurable.t/0","type":"type"},{"doc":"An interface for configuring and applying featurizers.\n\nA featurizer is used to convert raw data into model input.\n\nEvery module implementing this behaviour is expected to also define\na configuration struct.","ref":"Bumblebee.Featurizer.html","title":"Bumblebee.Featurizer","type":"behaviour"},{"doc":"Performs feature extraction on the given input.","ref":"Bumblebee.Featurizer.html#c:apply/3","title":"Bumblebee.Featurizer.apply/3","type":"callback"},{"doc":"","ref":"Bumblebee.Featurizer.html#t:t/0","title":"Bumblebee.Featurizer.t/0","type":"type"},{"doc":"An interface for configuring and building models based on the same\narchitecture.\n\nEvery module implementing this behaviour is expected to also define\na configuration struct.","ref":"Bumblebee.ModelSpec.html","title":"Bumblebee.ModelSpec","type":"behaviour"},{"doc":"Returns the list of supported model architectures.","ref":"Bumblebee.ModelSpec.html#c:architectures/0","title":"Bumblebee.ModelSpec.architectures/0","type":"callback"},{"doc":"Builds a template input for the model.\n\nThe template is used to compile the model when initializing parameters.","ref":"Bumblebee.ModelSpec.html#c:input_template/1","title":"Bumblebee.ModelSpec.input_template/1","type":"callback"},{"doc":"Builds an `Axon` model according to the given configuration.","ref":"Bumblebee.ModelSpec.html#c:model/1","title":"Bumblebee.ModelSpec.model/1","type":"callback"},{"doc":"","ref":"Bumblebee.ModelSpec.html#t:t/0","title":"Bumblebee.ModelSpec.t/0","type":"type"},{"doc":"An interface for configuring and using schedulers.\n\nA scheduler defines a sampling method, usually used for multi-step\ndenoising process, as in stable diffusion.\n\nEvery module implementing this behaviour is expected to also define\na configuration struct.","ref":"Bumblebee.Scheduler.html","title":"Bumblebee.Scheduler","type":"behaviour"},{"doc":"Imagine a denoising model trained in 1000 steps. During training,\nwe take some original data and add random noise 1000 times, this\nway we obtain 1000 steps with increasing level of noise. Then, the\nmodel learns to predict noise at each timestep, given data at that\nstep (sample) and the timestep.\n\nOnce such model is trained, we can obtain brand new data (such as\nimage) by generating random data and denoising it with our model in\n1000 steps.\n\nDoing 1000 forward passes of the model for a single generation can\nbe expensive, hence multiple methods have been developed to reduce\nthe number of steps during denoising, with no changes to the model.\n\nEach method specifies a subset of the original timesteps, at each\ntimestep we need to do a forward pass of the model (or possibly a\nfew), then the method extrapolates the sample to the next selected\ntimestep, possibly skipping a lot of timesteps in between.","ref":"Bumblebee.Scheduler.html#module-context","title":"Context - Bumblebee.Scheduler","type":"behaviour"},{"doc":"Throughout the docs and APIs the word \"steps\" refers to diffusion\nsteps, whereas \"timesteps\" is more specific and refers to the exact\nvalues $t$ (points in time).","ref":"Bumblebee.Scheduler.html#module-note-on-wording","title":"Note on wording - Bumblebee.Scheduler","type":"behaviour"},{"doc":"Initializes state for a new scheduler loop.\n\nReturns a pair of `{state, timesteps}`, where `state` is an opaque\n`Nx.Container` and `timesteps` is a tensor with the subsequent\ntimesteps for model forward pass.","ref":"Bumblebee.Scheduler.html#c:init/3","title":"Bumblebee.Scheduler.init/3","type":"callback"},{"doc":"Predicts sample at the previous timestep.\n\nTakes the current `sample` and `prediction` (usually noise) returned\nby the model at the current timestep. Returns `{state, prev_sample}`,\nwhere `state` is the updated state and `prev_sample` is the predicted\nsample at the previous timestep.","ref":"Bumblebee.Scheduler.html#c:step/4","title":"Bumblebee.Scheduler.step/4","type":"callback"},{"doc":"","ref":"Bumblebee.Scheduler.html#t:state/0","title":"Bumblebee.Scheduler.state/0","type":"type"},{"doc":"","ref":"Bumblebee.Scheduler.html#t:t/0","title":"Bumblebee.Scheduler.t/0","type":"type"},{"doc":"An interface for language models supporting sequence generation.","ref":"Bumblebee.Text.Generation.html","title":"Bumblebee.Text.Generation","type":"behaviour"},{"doc":"Builds a numerical definition that generates sequences of tokens using\nthe given language model.\n\nThe model should be either a decoder or an encoder-decoder. The tokens\nare generated by iterative inference using the decoder (autoregression),\nuntil the termination criteria are met.\n\nIn case of encoder-decoder models, the corresponding encoder is run\nonly once and the intermediate state is reused during all iterations.\n\nThe generation is controlled by a number of options given as\n`%Bumblebee.Text.GenerationConfig{}`, see the corresponding docs\nfor more details.","ref":"Bumblebee.Text.Generation.html#build_generate/4","title":"Bumblebee.Text.Generation.build_generate/4","type":"function"},{"doc":"* `:seed` - random seed to use when sampling. By default the current\n    timestamp is used","ref":"Bumblebee.Text.Generation.html#build_generate/4-options","title":"Options - Bumblebee.Text.Generation.build_generate/4","type":"function"},{"doc":"Initializes an opaque cache input for iterative inference.","ref":"Bumblebee.Text.Generation.html#init_cache/4","title":"Bumblebee.Text.Generation.init_cache/4","type":"function"},{"doc":"Initializes an opaque cache input for iterative inference.","ref":"Bumblebee.Text.Generation.html#c:init_cache/4","title":"Bumblebee.Text.Generation.init_cache/4","type":"callback"},{"doc":"Calls `fun` for every batched tensor in the cache.","ref":"Bumblebee.Text.Generation.html#traverse_cache/3","title":"Bumblebee.Text.Generation.traverse_cache/3","type":"function"},{"doc":"Traverses all batched tensors in the cache.\n\nThis function is used when the cache needs to be inflated or\ndeflated for a different batch size.","ref":"Bumblebee.Text.Generation.html#c:traverse_cache/3","title":"Bumblebee.Text.Generation.traverse_cache/3","type":"callback"},{"doc":"","ref":"Bumblebee.Text.Generation.html#t:cache/0","title":"Bumblebee.Text.Generation.cache/0","type":"type"},{"doc":"An interface for configuring and applying tokenizers.\n\nA tokenizer is used to convert raw text data into model input.\n\nEvery module implementing this behaviour is expected to also define\na configuration struct.","ref":"Bumblebee.Tokenizer.html","title":"Bumblebee.Tokenizer","type":"behaviour"},{"doc":"Performs tokenization and encoding on the given input.","ref":"Bumblebee.Tokenizer.html#c:apply/3","title":"Bumblebee.Tokenizer.apply/3","type":"callback"},{"doc":"Decodes a list of token ids into a sentence.","ref":"Bumblebee.Tokenizer.html#decode/2","title":"Bumblebee.Tokenizer.decode/2","type":"function"},{"doc":"Decodes a list of token ids into a sentence.","ref":"Bumblebee.Tokenizer.html#c:decode/2","title":"Bumblebee.Tokenizer.decode/2","type":"callback"},{"doc":"Converts the given token id the corresponding token.","ref":"Bumblebee.Tokenizer.html#id_to_token/2","title":"Bumblebee.Tokenizer.id_to_token/2","type":"function"},{"doc":"Converts the given token id the corresponding token.","ref":"Bumblebee.Tokenizer.html#c:id_to_token/2","title":"Bumblebee.Tokenizer.id_to_token/2","type":"callback"},{"doc":"Returns a special token by name.","ref":"Bumblebee.Tokenizer.html#special_token/2","title":"Bumblebee.Tokenizer.special_token/2","type":"function"},{"doc":"Returns id of a special token by name.","ref":"Bumblebee.Tokenizer.html#special_token_id/2","title":"Bumblebee.Tokenizer.special_token_id/2","type":"function"},{"doc":"Returns a map with special tokens.","ref":"Bumblebee.Tokenizer.html#c:special_tokens/1","title":"Bumblebee.Tokenizer.special_tokens/1","type":"callback"},{"doc":"Converts the given token into the corresponding numeric id.","ref":"Bumblebee.Tokenizer.html#token_to_id/2","title":"Bumblebee.Tokenizer.token_to_id/2","type":"function"},{"doc":"Converts the given token into the corresponding numeric id.","ref":"Bumblebee.Tokenizer.html#c:token_to_id/2","title":"Bumblebee.Tokenizer.token_to_id/2","type":"callback"},{"doc":"","ref":"Bumblebee.Tokenizer.html#t:input/0","title":"Bumblebee.Tokenizer.input/0","type":"type"},{"doc":"A type corresponding to a special token in the vocabulary.","ref":"Bumblebee.Tokenizer.html#t:special_token_type/0","title":"Bumblebee.Tokenizer.special_token_type/0","type":"type"},{"doc":"* `:bos` - a token representing the beginning of a sentence\n\n  * `:eos` - a token representing the end of a sentence\n\n  * `:unk` - a token representing an out-of-vocabulary token\n\n  * `:sep` - a token separating two different sentences in the same\n    input\n\n  * `:pad` - a token added when processing a batch of sequences with\n    different length\n\n  * `:cls` - a token representing the class of the input\n\n  * `:mask` - a token representing a masked token, used for masked\n    language modeling tasks","ref":"Bumblebee.Tokenizer.html#t:special_token_type/0-common-types","title":"Common types - Bumblebee.Tokenizer.special_token_type/0","type":"type"},{"doc":"","ref":"Bumblebee.Tokenizer.html#t:t/0","title":"Bumblebee.Tokenizer.t/0","type":"type"},{"doc":"","ref":"Bumblebee.Tokenizer.html#t:token/0","title":"Bumblebee.Tokenizer.token/0","type":"type"},{"doc":"","ref":"Bumblebee.Tokenizer.html#t:token_id/0","title":"Bumblebee.Tokenizer.token_id/0","type":"type"},{"doc":"A set of configuration options controlling text generation.\n\nThis struct is expected by `Bumblebee.Text.Generation.build_generate/3`.","ref":"Bumblebee.Text.GenerationConfig.html","title":"Bumblebee.Text.GenerationConfig","type":"module"},{"doc":"#","ref":"Bumblebee.Text.GenerationConfig.html#module-configuration","title":"Configuration - Bumblebee.Text.GenerationConfig","type":"module"},{"doc":"* `:max_new_tokens` - the maximum number of tokens to be generated, ignoring the number of tokens in the prompt. Defaults to `20`\n\n  * `:min_new_tokens` - the minimum number of tokens to be generated, ignoring the number of tokens in the prompt\n\n  * `:max_length` - the maximum length of the sequence to be generated. Note that this length includes the\n    length of the input prompt (including padding). In general, prefer `:max_new_tokens`,\n    which ignores the number of tokens in the prompt\n    \n\n  * `:min_length` - the minimum length of the sequence to be generated. Note that this length includes the\n    length of the input prompt (including padding). In general, prefer `:min_new_tokens`,\n    which ignores the number of tokens in the prompt\n    \n\n#","ref":"Bumblebee.Text.GenerationConfig.html#module-options-controlling-length","title":"Options controlling length - Bumblebee.Text.GenerationConfig","type":"module"},{"doc":"* `:strategy` - the method deciding how tokens are selected, it has a significant impact on the quality\n    of the generated sequence. Should be a map with `:type` and strategy-specific options.\n    \n      * `:greedy_search` - the most straightforward approach, where in\n        every iteration the most probable token (as given by the model)\n        is taken.\n    \n        Example: `%{type: :greedy_search}`.\n    \n      * `:contrastive_search` - state-of-the-art decoding method, capable\n        of producing high quality, coherent sequences. The results are\n        deterministic. See [this article](https://huggingface.co/blog/introducing-csearch)\n        for more details.\n    \n          * `:top_k` (required) - the number of highest probability vocabulary tokens considered\n            as a continuation\n    \n          * `:alpha` (required) - the weight of degeneration penalty. It balances the model\n            confidence and the penalty\n    \n        Example: `%{type: :contrastive_search, top_k: 4, alpha: 0.6}`.\n    \n      * `:multinomial_sampling` - this method samples tokens according to the probability\n        distribution given by the model. The results are nondeterministic, unless a seed\n        is specified.\n    \n          * `:top_k` (optional) - when specified, restricts sampling to top-k most probable\n            candidates\n    \n          * `:top_p` (optional) - when specified, restricts sampling to tokens which probabilities\n            add up to top-p\n    . Defaults to `%{type: :greedy_search}`\n\n#","ref":"Bumblebee.Text.GenerationConfig.html#module-options-controlling-strategy","title":"Options controlling strategy - Bumblebee.Text.GenerationConfig","type":"module"},{"doc":"* `:decoder_start_token_id` - the id of the initial token when generating from scratch, in case of encoder-decoder models\n\n  * `:forced_bos_token_id` - the id of the token to force as the first generated token\n\n  * `:forced_eos_token_id` - the id of the token to force as the last generated token when `:max_length` is reached\n\n  * `:forced_token_ids` - a list of `{index, token_id}` pairs forcing `token_id` to appear at `index` in the generated sequence. Defaults to `[]`\n\n  * `:no_repeat_ngram_length` - when set, n-grams of the given length can occur only once in the generated sequence\n\n#","ref":"Bumblebee.Text.GenerationConfig.html#module-options-controlling-generated-tokens","title":"Options controlling generated tokens - Bumblebee.Text.GenerationConfig","type":"module"},{"doc":"* `:bos_token_id` - the id of the beginning-of-sequence token\n\n  * `:eos_token_id` - the id of the end-of-sequence token\n\n  * `:pad_token_id` - the id of the padding token","ref":"Bumblebee.Text.GenerationConfig.html#module-special-tokens-used-during-generation","title":"Special tokens used during generation - Bumblebee.Text.GenerationConfig","type":"module"},{"doc":"","ref":"Bumblebee.Text.GenerationConfig.html#t:t/0","title":"Bumblebee.Text.GenerationConfig.t/0","type":"type"},{"doc":"# Examples\n\n```elixir\nMix.install([\n  {:bumblebee, github: \"elixir-nx/bumblebee\"},\n  {:nx, \"~> 0.5.1\"},\n  {:exla, \"~> 0.5.1\"},\n  {:axon, \"~> 0.5.1\"},\n  {:kino, \"~> 0.8.0\"}\n])\n\nNx.global_default_backend(EXLA.Backend)\n```","ref":"examples.html","title":"Examples","type":"extras"},{"doc":"In this notebook we go through a number of examples to get a quick overview of what Bumblebee brings to the table.","ref":"examples.html#introduction","title":"Introduction - Examples","type":"extras"},{"doc":"Let's start with image classification. First, we load a pre-trained [ResNet-50](https://huggingface.co/microsoft/resnet-50) model from a HuggingFace repository. We also load the corresponding featurizer for preprocessing input images.\n\n```elixir\n{:ok, resnet} = Bumblebee.load_model({:hf, \"microsoft/resnet-50\"})\n{:ok, featurizer} = Bumblebee.load_featurizer({:hf, \"microsoft/resnet-50\"})\n\n:ok\n```\n\nNext, we use the high-level API to build an end-to-end task definition on top of the model we just loaded. We will also need an image to work with, so let's show an image input.\n\n```elixir\nserving = Bumblebee.Vision.image_classification(resnet, featurizer)\n\nimage_input = Kino.Input.image(\"Image\", size: {224, 224})\n```\n\nBumblebee implements end-to-end tasks using `Nx.Serving`. With serving we can choose to either do a one-off run, or to start a supervised process that automatically batches multiple inference requests. Thanks to this abstraction we can do quick experimentation and then plug the task into a production app with minimal effort.\n\nIn this case we will do the one-off run for the selected image:\n\n```elixir\nimage = Kino.Input.read(image_input)\n\n# Build a tensor from the raw pixel data\nimage =\n  image.data\n  |> Nx.from_binary(:u8)\n  |> Nx.reshape({image.height, image.width, 3})\n\nNx.Serving.run(serving, image)\n```\n\n#","ref":"examples.html#image-classification","title":"Image classification - Examples","type":"extras"},{"doc":"Note that we are dealing with regular `Axon` models and the high-level API is just a convenience. If you need full control over the inference flow, you can do it manually. In this case, we would pass the image through the featurizer to get normalized model inputs, then we would run the model and finally extract the most probable label.\n\n```elixir\ninputs = Bumblebee.apply_featurizer(featurizer, image)\noutputs = Axon.predict(resnet.model, resnet.params, inputs)\n\nid = outputs.logits |> Nx.argmax() |> Nx.to_number()\nresnet.spec.id_to_label[id]\n```\n\nYou can try a number of other models, just replace the repository id with one of these:\n\n* [**facebook/convnext-tiny-224**](https://huggingface.co/facebook/convnext-tiny-224) (ConvNeXT)\n\n* [**google/vit-base-patch16-224**](https://huggingface.co/google/vit-base-patch16-224) (ViT)\n\n* [**facebook/deit-base-distilled-patch16-224**](https://huggingface.co/facebook/deit-base-distilled-patch16-224) (DeiT)","ref":"examples.html#manual-inference","title":"Manual inference - Examples","type":"extras"},{"doc":"Now time for some text processing. Specifically, we want to fill in the missing word in a sentence. This time we load the [BERT](https://huggingface.co/bert-base-uncased) model together with a matching tokenizer. We will use the tokenizer to preprocess our text input.\n\n```elixir\n{:ok, bert} = Bumblebee.load_model({:hf, \"bert-base-uncased\"})\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"bert-base-uncased\"})\n\nserving = Bumblebee.Text.fill_mask(bert, tokenizer)\n\ntext_input = Kino.Input.text(\"Sentence with mask\", default: \"The capital of [MASK] is Paris.\")\n```\n\n```elixir\ntext = Kino.Input.read(text_input)\n\nNx.Serving.run(serving, text)\n```\n\nAgain, you can try other models, such as [**albert-base-v2**](https://huggingface.co/albert-base-v2) or [**roberta-base**](https://huggingface.co/roberta-base).","ref":"examples.html#fill-mask","title":"Fill-mask - Examples","type":"extras"},{"doc":"In this example we will analyze text sentiment.\n\nWe will use the [BERTweet](https://huggingface.co/finiteautomata/bertweet-base-sentiment-analysis) model, trained to classify text into one of three categories: positive (POS), negative (NEG) or neutral (NEU).\n\n```elixir\n{:ok, bertweet} = Bumblebee.load_model({:hf, \"finiteautomata/bertweet-base-sentiment-analysis\"})\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"vinai/bertweet-base\"})\n\nserving = Bumblebee.Text.text_classification(bertweet, tokenizer)\n\ntext_input = Kino.Input.text(\"Text\", default: \"This cat is so cute.\")\n```\n\n*Note: this time we need to load a matching tokenizer from a different repository.*\n\n```elixir\ntext = Kino.Input.read(text_input)\nNx.Serving.run(serving, text)\n```","ref":"examples.html#text-classification","title":"Text classification - Examples","type":"extras"},{"doc":"In this section we look at token classification, more specifically named-entity recognition (NER), where the objective is to identify and categorize entities in text. We will once again use a fine-tuned [BERT](https://huggingface.co/dslim/bert-base-NER) model.\n\n```elixir\n{:ok, bert} = Bumblebee.load_model({:hf, \"dslim/bert-base-NER\"})\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"bert-base-cased\"})\n\nserving = Bumblebee.Text.token_classification(bert, tokenizer, aggregation: :same)\n\ntext_input =\n  Kino.Input.text(\"Text\",\n    default: \"Rachel Green works at Ralph Lauren in New York City in the sitcom Friends\"\n  )\n```\n\n```elixir\ntext = Kino.Input.read(text_input)\nNx.Serving.run(serving, text)\n```","ref":"examples.html#named-entity-recognition","title":"Named-entity recognition - Examples","type":"extras"},{"doc":"Generation is where things get even more exciting. In this section w will use the extremely popular [GPT-2](https://huggingface.co/gpt2) model to generate text continuation.\n\nGeneration generally is an iterative process, where the model predicts the sentence token by token, adhering to some constraints. Again, we will make use of a higher-level API based on `Nx.Serving`.\n\n```elixir\n{:ok, gpt2} = Bumblebee.load_model({:hf, \"gpt2\"})\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"gpt2\"})\n{:ok, generation_config} = Bumblebee.load_generation_config({:hf, \"gpt2\"})\n\nserving = Bumblebee.Text.generation(gpt2, tokenizer, generation_config)\n\ntext_input = Kino.Input.text(\"Text\", default: \"Yesterday, I was reading a book and\")\n```\n\n```elixir\ntext = Kino.Input.read(text_input)\nNx.Serving.run(serving, text)\n```\n\nThere is also [gpt2-medium](https://huggingface.co/gpt2-medium) and [gpt2-large](https://huggingface.co/gpt2-large) - heavier versions of the model with much more parameters.","ref":"examples.html#text-generation","title":"Text generation - Examples","type":"extras"},{"doc":"Another text-related task is question answering, where the objective is to retrieve the answer to a question based on a given text. We will work with a [RoBERTa](https://huggingface.co/deepset/roberta-base-squad2) model trained to do just that.\n\n```elixir\n{:ok, roberta} = Bumblebee.load_model({:hf, \"deepset/roberta-base-squad2\"})\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"roberta-base\"})\n\nserving = Bumblebee.Text.question_answering(roberta, tokenizer)\n\nquestion_input =\n  Kino.Input.text(\"Question\",\n    default: \"Which name is also used to describe the Amazon rainforest in English?\"\n  )\n\ncontext_input =\n  Kino.Input.textarea(\"Context\",\n    default:\n      ~s/The Amazon rainforest (Portuguese: Floresta Amazônica or Amazônia; Spanish: Selva Amazónica, Amazonía or usually Amazonia; French: Forêt amazonienne; Dutch: Amazoneregenwoud), also known in English as Amazonia or the Amazon Jungle, is a moist broadleaf forest that covers most of the Amazon basin of South America. This basin encompasses 7,000,000 square kilometres (2,700,000 sq mi), of which 5,500,000 square kilometres (2,100,000 sq mi) are covered by the rainforest. This region includes territory belonging to nine nations. The majority of the forest is contained within Brazil, with 60% of the rainforest, followed by Peru with 13%, Colombia with 10%, and with minor amounts in Venezuela, Ecuador, Bolivia, Guyana, Suriname and French Guiana. States or departments in four nations contain \"Amazonas\" in their names. The Amazon represents over half of the planet's remaining rainforests, and comprises the largest and most biodiverse tract of tropical rainforest in the world, with an estimated 390 billion individual trees divided into 16,000 species./\n  )\n\nKino.Layout.grid([question_input, context_input])\n```\n\n```elixir\nquestion = Kino.Input.read(question_input)\ncontext = Kino.Input.read(context_input)\nNx.Serving.run(serving, %{question: question, context: context})\n```","ref":"examples.html#question-answering","title":"Question answering - Examples","type":"extras"},{"doc":"The examples we covered should give you a good idea of what Bumblebee is about. We are excited about enabling easy access to the pre-trained, powerful deep learning models in Elixir. We are actively working on adding more models and high-level APIs, so stay tuned 🚀","ref":"examples.html#final-notes","title":"Final notes - Examples","type":"extras"},{"doc":"# Stable Diffusion\n\n```elixir\nMix.install([\n  {:bumblebee, \"~> 0.3.0\"},\n  {:nx, \"~> 0.5.1\"},\n  {:exla, \"~> 0.5.1\"},\n  {:kino, \"~> 0.8.0\"}\n])\n\nNx.global_default_backend(EXLA.Backend)\n```","ref":"stable_diffusion.html","title":"Stable Diffusion","type":"extras"},{"doc":"Stable Diffusion is a latent text-to-image diffusion model, primarily used to generate images based on a text prompt. Ever since it [became open-source](https://stability.ai/blog/stable-diffusion-public-release), the research, applications and tooling around it exploded. You can find a ton of resources and examples online, meanwhile let's see how to run Stable Diffusion using Bumblebee!\n\n \n\n> **Note:** Stable Diffusion is a very involved model, so the generation can take a long time if you run it on a CPU. Also, running on the GPU currently requires at least 10 GB of VRAM.","ref":"stable_diffusion.html#introduction","title":"Introduction - Stable Diffusion","type":"extras"},{"doc":"Stable Diffusion is composed of several separate models and preprocessors, so we will load all of them.\n\n```elixir\nrepository_id = \"CompVis/stable-diffusion-v1-4\"\n\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"openai/clip-vit-large-patch14\"})\n\n{:ok, clip} = Bumblebee.load_model({:hf, repository_id, subdir: \"text_encoder\"})\n\n{:ok, unet} =\n  Bumblebee.load_model({:hf, repository_id, subdir: \"unet\"},\n    params_filename: \"diffusion_pytorch_model.bin\"\n  )\n\n{:ok, vae} =\n  Bumblebee.load_model({:hf, repository_id, subdir: \"vae\"},\n    architecture: :decoder,\n    params_filename: \"diffusion_pytorch_model.bin\"\n  )\n\n{:ok, scheduler} = Bumblebee.load_scheduler({:hf, repository_id, subdir: \"scheduler\"})\n{:ok, featurizer} = Bumblebee.load_featurizer({:hf, repository_id, subdir: \"feature_extractor\"})\n{:ok, safety_checker} = Bumblebee.load_model({:hf, repository_id, subdir: \"safety_checker\"})\n\n:ok\n```\n\n> **Note:** some checkpoints, such as [runwayml/stable-diffusion-v1-5](https://huggingface.co/runwayml/stable-diffusion-v1-5), require a license agreement. In those cases, sign up on Hugging Face, accept the license on the repository page, generate an access token in [the settings](https://huggingface.co/settings/tokens) and add it to the repository specification via `:auth_token`. You can use Livebook secrets to pass the token securely.\n\n \n\nWith all the models loaded, we can now configure a serving implementation of the text-to-image task.\n\n```elixir\nserving =\n  Bumblebee.Diffusion.StableDiffusion.text_to_image(clip, unet, vae, tokenizer, scheduler,\n    num_steps: 20,\n    num_images_per_prompt: 2,\n    safety_checker: safety_checker,\n    safety_checker_featurizer: featurizer,\n    compile: [batch_size: 1, sequence_length: 60],\n    defn_options: [compiler: EXLA]\n  )\n\nprompt_input =\n  Kino.Input.text(\"Prompt\", default: \"numbat, forest, high quality, detailed, digital art\")\n\nnegative_prompt_input = Kino.Input.text(\"Negative Prompt\", default: \"darkness, rainy, foggy\")\n\nKino.Layout.grid([prompt_input, negative_prompt_input])\n```\n\nWe are ready to generate images!\n\n```elixir\nprompt = Kino.Input.read(prompt_input)\nnegative_prompt = Kino.Input.read(negative_prompt_input)\n\noutput = Nx.Serving.run(serving, %{prompt: prompt, negative_prompt: negative_prompt})\n\nfor result   Kino.Layout.grid(columns: 2)\n```\n\nTo achieve a better quality you can increase the number of steps and images.","ref":"stable_diffusion.html#text-to-image","title":"Text to image - Stable Diffusion","type":"extras"},{"doc":"# Fine-tuning\n\n```elixir\nMix.install([\n  {:bumblebee, \"~> 0.3.0\"},\n  {:axon, \"~> 0.5.1\"},\n  {:nx, \"~> 0.5.1\"},\n  {:exla, \"~> 0.5.1\"},\n  {:explorer, \"~> 0.5.0\"}\n])\n```\n\n \n\n```\n:ok\n```","ref":"fine_tuning.html","title":"Fine-tuning","type":"extras"},{"doc":"```elixir\nNx.default_backend(EXLA.Backend)\n```\n\n \n\n```\n{Nx.BinaryBackend, []}\n```\n\nFine-tuning is the process of specializing the parameters in a pre-trained model to a specific task. Large-language models such as BERT train on a generic langauge-modeling task which makes them powerful at extracting features from text. Despite their power, you often still need to train them on a downstream task.\n\nThis example demonstrates how to use Bumblebee and Axon to fine-tune a pre-trained Bert model to classify Yelp reviews into classes of 1-5 stars. This example is based on [Fine-tune a pretrained model](https://huggingface.co/docs/transformers/training) from Huggingface.\n\nYou'll need to first download the Yelp Reviews dataset ([download](https://s3.amazonaws.com/fast-ai-nlp/yelp_review_full_csv.tgz)).\n\nOnce downloaded, extract it to a directory of your choosing and you're ready to go!","ref":"fine_tuning.html#introduction","title":"Introduction - Fine-tuning","type":"extras"},{"doc":"We'll start by loading a pre-trained model and tokenizer; however, we'll initialize the model to have an untrained sequence classification head.\n\nReviews in the dataset can have anywhere from 1 to 5 stars, which means we need 5 labels in our sequence classification head. We can change the default configuration by loading the model spec with `Bumblebee.load_spec/2` and making changes to spec properties with `Bumblebee.configure/2`.\n\nThe pre-trained model we'll be using is `bert-base-cased`; however, you can use any of the supported models from the HuggingFace Hub.\n\n```elixir\n{:ok, spec} =\n  Bumblebee.load_spec({:hf, \"bert-base-cased\"},\n    architecture: :for_sequence_classification\n  )\n\nspec = Bumblebee.configure(spec, num_labels: 5)\n\n{:ok, model} = Bumblebee.load_model({:hf, \"bert-base-cased\"}, spec: spec)\n{:ok, tokenizer} = Bumblebee.load_tokenizer({:hf, \"bert-base-cased\"})\n```\n\n \n\n```\n\n14:41:33.314 [info] TfrtCpuClient created.\n\n14:41:33.820 [debug] the following parameters were missing:\n\n  * sequence_classification_head.output.kernel\n  * sequence_classification_head.output.bias\n\n\n14:41:33.820 [debug] the following PyTorch parameters were unused:\n\n  * cls.predictions.bias\n  * cls.predictions.decoder.weight\n  * cls.predictions.transform.LayerNorm.beta\n  * cls.predictions.transform.LayerNorm.gamma\n  * cls.predictions.transform.dense.bias\n  * cls.predictions.transform.dense.weight\n  * cls.seq_relationship.bias\n  * cls.seq_relationship.weight\n\n\n```\n\n \n\n```\n{:ok,\n %Bumblebee.Text.BertTokenizer{\n   tokenizer: #Tokenizers.Tokenizer ,\n   special_tokens: %{cls: \"[CLS]\", mask: \"[MASK]\", pad: \"[PAD]\", sep: \"[SEP]\", unk: \"[UNK]\"}\n }}\n```","ref":"fine_tuning.html#load-a-model","title":"Load a model - Fine-tuning","type":"extras"},{"doc":"With the models downloaded and ready to go, you need to prepare the dataset. The downloaded dataset is a CSV. You can use the `Explorer` library to quickly load the CSV into a DataFrame.\n\nOnce the data is loaded, you need to convert raw text to tokens and the raw labels to tensors. Additionally, you need to convert the DataFrame to a Stream consisting of tuples: `{tokenized, labels}` - that is the form expected by Axon's training API.\n\n```elixir\ndefmodule Yelp do\n  def load(path, tokenizer, opts \\\\ []) do\n    path\n    |> Explorer.DataFrame.from_csv!(header: false)\n    |> Explorer.DataFrame.rename([\"label\", \"text\"])\n    |> stream()\n    |> tokenize_and_batch(tokenizer, opts[:batch_size], opts[:sequence_length])\n  end\n\n  def stream(df) do\n    xs = df[\"text\"]\n    ys = df[\"label\"]\n\n    xs\n    |> Explorer.Series.to_enum()\n    |> Stream.zip(Explorer.Series.to_enum(ys))\n  end\n\n  def tokenize_and_batch(stream, tokenizer, batch_size, sequence_length) do\n    stream\n    |> Stream.chunk_every(batch_size)\n    |> Stream.map(fn batch ->\n      {text, labels} = Enum.unzip(batch)\n      tokenized = Bumblebee.apply_tokenizer(tokenizer, text, length: sequence_length)\n      {tokenized, Nx.stack(labels)}\n    end)\n  end\nend\n```\n\n \n\n```\n{:module, Yelp,  >, {:tokenize_and_batch, 4}}\n```\n\nNow you can use the `Yelp.load/2` function to load a training set and a testing set:\n\n```elixir\nbatch_size = 32\nsequence_length = 64\n\ntrain_data =\n  Yelp.load(\"~/yelp/yelp_review_full_csv/train.csv\", tokenizer,\n    batch_size: batch_size,\n    sequence_length: sequence_length\n  )\n\ntest_data =\n  Yelp.load(\"~/yelp/yelp_review_full_csv/test.csv\", tokenizer,\n    batch_size: batch_size,\n    sequence_length: sequence_length\n  )\n```\n\n \n\n```\n#Stream ,\n    funs: [#Function ]\n  ]>,\n  funs: [#Function ]\n]>\n```\n\nYou can see what a single batch looks like by grabbing 1 from the stream:\n\n```elixir\nEnum.take(train_data, 1)\n```\n\n \n\n```\n[\n  {%{\n     \"attention_mask\" => #Nx.Tensor \n       [\n         [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, ...],\n         ...\n       ]\n     >,\n     \"input_ids\" => #Nx.Tensor \n       [\n         [101, 173, 1197, 119, 2284, 2953, 3272, 1917, 178, 1440, 1111, 1107, 170, 1704, 22351, 119, 1119, 112, 188, 3505, 1105, 3123, 1106, 2037, 1106, 1443, 1217, 10063, 4404, 132, 1119, 112, 188, 1579, 1113, 1159, 1107, 3195, 1117, 4420, 132, 1119, 112, 188, 6559, 1114, ...],\n         ...\n       ]\n     >,\n     \"token_type_ids\" => #Nx.Tensor \n       [\n         [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, ...],\n         ...\n       ]\n     >\n   },\n   #Nx.Tensor \n     [5, 2, 4, 4, 1, 5, 5, 1, 2, 3, 1, 1, 4, 2, 5, 5, 5, 5, 5, 5, 4, 3, 2, 5, 1, 1, 1, 2, 2, 4, 2, 2]\n   >}\n]\n```\n\nThe dataset is rather large for CPU training, so we'll just train a small subset (250 training batches and 50 testing batches):\n\n```elixir\ntrain_data = Enum.take(train_data, 250)\ntest_data = Enum.take(test_data, 50)\n:ok\n```\n\n \n\n```\n:ok\n```","ref":"fine_tuning.html#prepare-a-dataset","title":"Prepare a dataset - Fine-tuning","type":"extras"},{"doc":"Now we can go about training the model! First, we need to extract the Axon model and parameters from the Bumblebee model map:\n\n```elixir\n%{model: model, params: params} = model\n\nmodel\n```\n\n \n\n```\n#Axon \n```\n\nThe Axon model actually outputs a map with `:logits`, `:hidden_states`, and `:attentions`. You can see this by using `Axon.get_output_shape/2` with an input. This method symbolically executes the graph and gets the resulting shapes:\n\n```elixir\n[{input, _}] = Enum.take(train_data, 1)\nAxon.get_output_shape(model, input)\n```\n\n \n\n```\n%{attentions: #Axon.None , hidden_states: #Axon.None , logits: {32, 5}}\n```\n\nFor training, we only care about the `:logits` key, so we'll extract that by attaching an `Axon.nx/2` layer to the model:\n\n```elixir\nlogits_model = Axon.nx(model, & &1.logits)\n```\n\n \n\n```\n#Axon \n```\n\nNow we can declare our training loop. You can construct Axon training loops using the `Axon.Loop.trainer/3` factory method with a model, loss function, and optimizer. We'll also adjust the log-settings to more frequently log metrics to standard out:\n\n```elixir\nloss =\n  &Axon.Losses.categorical_cross_entropy(&1, &2,\n    reduction: :mean,\n    from_logits: true,\n    sparse: true\n  )\n\noptimizer = Axon.Optimizers.adam(5.0e-5)\n\nloop = Axon.Loop.trainer(logits_model, loss, optimizer, log: 1)\n```\n\n \n\n```\n#Axon.Loop ,\n     #Function }\n  },\n  handlers: %{\n    completed: [],\n    epoch_completed: [\n      {#Function ,\n       #Function }\n    ],\n    epoch_halted: [],\n    epoch_started: [],\n    halted: [],\n    iteration_completed: [\n      {#Function ,\n       #Function }\n    ],\n    iteration_started: [],\n    started: []\n  },\n  ...\n>\n```\n\nThe call to trainer just returns a data structure. In Axon, we manipulate this data structure to control different parts of the loop. For example, you can attach metrics:\n\n```elixir\naccuracy = &Axon.Metrics.accuracy(&1, &2, from_logits: true, sparse: true)\n\nloop = Axon.Loop.metric(loop, accuracy, \"accuracy\")\n```\n\n \n\n```\n#Axon.Loop ,\n     #Function },\n    \"loss\" => {#Function ,\n     #Function }\n  },\n  handlers: %{\n    completed: [],\n    epoch_completed: [\n      {#Function ,\n       #Function }\n    ],\n    epoch_halted: [],\n    epoch_started: [],\n    halted: [],\n    iteration_completed: [\n      {#Function ,\n       #Function }\n    ],\n    iteration_started: [],\n    started: []\n  },\n  ...\n>\n```\n\nAnd you can attach event handlers to do certain things, such as serialize the loop state at regular intervals so you don't lose your progress:\n\n```elixir\nloop = Axon.Loop.checkpoint(loop, event: :epoch_completed)\n```\n\n \n\n```\n#Axon.Loop ,\n     #Function },\n    \"loss\" => {#Function ,\n     #Function }\n  },\n  handlers: %{\n    completed: [],\n    epoch_completed: [\n      {#Function ,\n       #Function },\n      {#Function ,\n       #Function }\n    ],\n    epoch_halted: [],\n    epoch_started: [],\n    halted: [],\n    iteration_completed: [\n      {#Function ,\n       #Function }\n    ],\n    iteration_started: [],\n    started: []\n  },\n  ...\n>\n```\n\nTo run the loop, you just need to call `Axon.Loop.run/4`. `Axon.Loop.run/4` takes a loop, input data, and any initial state (in this case initial parameters). You can kind of think of `Axon.Loop.run/4` as an `Enum.reduce/3`. It takes data, an accumulator, and a function - which map to `Loop.run/4` input data, initial state, and the actual loop data structure.\n\nYou'll commonly see loops written out in long chains using Elixir's `|>` operator, like this:\n\n```elixir\ntrained_model_state =\n  logits_model\n  |> Axon.Loop.trainer(loss, optimizer, log: 1)\n  |> Axon.Loop.metric(accuracy, \"accuracy\")\n  |> Axon.Loop.checkpoint(event: :epoch_completed)\n  |> Axon.Loop.run(train_data, params, epochs: 3, compiler: EXLA, strict?: false)\n\n:ok\n```\n\n \n\n```\n\n02:46:02.170 [debug] Forwarding options: [compiler: EXLA] to JIT compiler\nEpoch: 0, Batch: 249, accuracy: 0.3462500 loss: 1.2216607\nEpoch: 1, Batch: 249, accuracy: 0.5186251 loss: 1.0558304\nEpoch: 2, Batch: 249, accuracy: 0.6236249 loss: 0.9317472\n```\n\n \n\n```\n:ok\n```","ref":"fine_tuning.html#train-the-model","title":"Train the model - Fine-tuning","type":"extras"},{"doc":"The training loop returns the final model state after training over your dataset for the given number of epochs. Axon uses the same `Axon.Loop` API to create evaluation loops as well. You can create one with the `Axon.Loop.evaluator/1` factory, instrument it with metrics, and run it on your data with your trained model state:\n\n```elixir\nlogits_model\n|> Axon.Loop.evaluator()\n|> Axon.Loop.metric(accuracy, \"accuracy\")\n|> Axon.Loop.run(test_data, trained_model_state, compiler: EXLA)\n```\n\n \n\n```\nBatch: 49, accuracy: 0.3675000\n```\n\n \n\n```\n%{\n  0 => %{\n    \"accuracy\" => #Nx.Tensor \n      0.36750003695487976\n    >\n  }\n}\n```","ref":"fine_tuning.html#evaluating-the-model","title":"Evaluating the model - Fine-tuning","type":"extras"}]}